theory ReconTest
imports "~~/src/HOL/TPTP/ATP_Problem_Import"
begin

(*
(This code is based on theory file from the "Leo2 and Satallax on the Sledgehammer Testbench" paper)

Crude test to try and reconstruct the proofs using Metis and Z3:
having them try to reprove the problems.
- They aren't given any relevant theorems from Isabelle's library.
- In this case their proof search serves as reconstruction.
- We checked to see if axioms/definition-set can be minimised,
  by removing those which don't appear in the Leo2 proof
  (which it turned out to be none).
*)

ML {* open ATP_Problem_Import *}

ML {*
fun run_metis ctxt timeout =
  let
    fun metis' i =
      SOLVE_TIMEOUT timeout "metis"
          (Metis_Tactic.metis_tac ATP_Proof_Reconstruct.partial_type_encs
               ATP_Proof_Reconstruct.default_metis_lam_trans ctxt [] i)
  in
    can_tac ctxt (metis' 1)
  end
*}

ML {*
fun run_smt ctxt smt timeout =
  can_tac ctxt (SOLVE_TIMEOUT timeout smt (smt_solver_tac smt ctxt 1))
*}

ML {*
val timeout = 10

fun do_file file_name =
  let
    val log_to_file = File.append (Path.explode "/tmp/recon_test.out")
    fun log_outcome prover success =
      let
        val msg =
          file_name ^ " " ^ prover ^ ": " ^ (if success then "Success" else "Failure")
      in Output.urgent_message msg; log_to_file (msg ^ "\n") end

    val thy = @{theory}
    val (conjs, assms, ctxt) =
      read_tptp_file thy (freeze_problem_consts thy o snd) file_name
    val conj = make_conj assms conjs

   (*
   val (a1, a2) = assms
   val _ = tracing ("conjectures:" ^ PolyML.makestring (length(conjs)))
   val _ = tracing ("assumptions:" ^ PolyML.makestring (length(a1)) ^ " and " ^ PolyML.makestring (length(a2)))
   *)

    val _ = log_outcome "metis" (run_metis ctxt timeout conj)
    fun run_prover f prover = log_outcome prover (f ctxt prover timeout conj)
    val _ = run_prover run_smt "z3"
  in () end
*}

ML {*
val tptp_files =
  ["$PROBLEM_LIST_PATH/AGT027^1.p.out",
   "$PROBLEM_LIST_PATH/AGT027^2.p.out",
   "$PROBLEM_LIST_PATH/AGT028^1.p.out",
   "$PROBLEM_LIST_PATH/AGT028^2.p.out",
   "$PROBLEM_LIST_PATH/AGT029^1.p.out",
   "$PROBLEM_LIST_PATH/AGT030^1.p.out",
   "$PROBLEM_LIST_PATH/AGT031^1.p.out",
   "$PROBLEM_LIST_PATH/AGT031^2.p.out",
   "$PROBLEM_LIST_PATH/AGT032^1.p.out",
   "$PROBLEM_LIST_PATH/AGT032^2.p.out",
   "$PROBLEM_LIST_PATH/AGT033^1.p.out",
   "$PROBLEM_LIST_PATH/AGT033^2.p.out",
   "$PROBLEM_LIST_PATH/AGT034^1.p.out",
   "$PROBLEM_LIST_PATH/AGT034^2.p.out",
   "$PROBLEM_LIST_PATH/AGT035^1.p.out",
   "$PROBLEM_LIST_PATH/AGT035^2.p.out",
   "$PROBLEM_LIST_PATH/AGT036^1.p.out",
   "$PROBLEM_LIST_PATH/AGT037^1.p.out",
   "$PROBLEM_LIST_PATH/AGT037^2.p.out",
   "$PROBLEM_LIST_PATH/AGT038^1.p.out",
   "$PROBLEM_LIST_PATH/AGT039^1.p.out",
   "$PROBLEM_LIST_PATH/AGT040^1.p.out",
   "$PROBLEM_LIST_PATH/AGT041^1.p.out",
   "$PROBLEM_LIST_PATH/ALG001^5.p.out",
   "$PROBLEM_LIST_PATH/ALG248^3.p.out",
   "$PROBLEM_LIST_PATH/ALG249^3.p.out",
   "$PROBLEM_LIST_PATH/ALG250^3.p.out",
   "$PROBLEM_LIST_PATH/ALG251^2.p.out",
   "$PROBLEM_LIST_PATH/ALG253^2.p.out",
   "$PROBLEM_LIST_PATH/ALG254^1.p.out",
   "$PROBLEM_LIST_PATH/ALG254^2.p.out",
   "$PROBLEM_LIST_PATH/ALG255^1.p.out",
   "$PROBLEM_LIST_PATH/ALG256^1.p.out",
   "$PROBLEM_LIST_PATH/ALG256^2.p.out",
   "$PROBLEM_LIST_PATH/ALG257^1.p.out",
   "$PROBLEM_LIST_PATH/ALG257^2.p.out",
   "$PROBLEM_LIST_PATH/ALG258^1.p.out",
   "$PROBLEM_LIST_PATH/ALG258^2.p.out",
   "$PROBLEM_LIST_PATH/ALG259^1.p.out",
   "$PROBLEM_LIST_PATH/ALG259^2.p.out",
   "$PROBLEM_LIST_PATH/ALG260^1.p.out",
   "$PROBLEM_LIST_PATH/ALG260^2.p.out",
   "$PROBLEM_LIST_PATH/ALG261^1.p.out",
   "$PROBLEM_LIST_PATH/ALG261^2.p.out",
   "$PROBLEM_LIST_PATH/ALG262^2.p.out",
   "$PROBLEM_LIST_PATH/ALG263^1.p.out",
   "$PROBLEM_LIST_PATH/ALG263^3.p.out",
   "$PROBLEM_LIST_PATH/ALG264^1.p.out",
   "$PROBLEM_LIST_PATH/ALG264^3.p.out",
   "$PROBLEM_LIST_PATH/ALG266^2.p.out",
   "$PROBLEM_LIST_PATH/ALG268^2.p.out",
   "$PROBLEM_LIST_PATH/ALG268^3.p.out",
   "$PROBLEM_LIST_PATH/ALG268^4.p.out",
   "$PROBLEM_LIST_PATH/ALG270^5.p.out",
   "$PROBLEM_LIST_PATH/ALG271^5.p.out",
   "$PROBLEM_LIST_PATH/ALG272^5.p.out",
   "$PROBLEM_LIST_PATH/ALG273^5.p.out",
   "$PROBLEM_LIST_PATH/ALG274^5.p.out",
   "$PROBLEM_LIST_PATH/ALG276^5.p.out",
   "$PROBLEM_LIST_PATH/ALG277^5.p.out",
   "$PROBLEM_LIST_PATH/ALG278^5.p.out",
   "$PROBLEM_LIST_PATH/ALG279^5.p.out",
   "$PROBLEM_LIST_PATH/ALG280^5.p.out",
   "$PROBLEM_LIST_PATH/ALG281^5.p.out",
   "$PROBLEM_LIST_PATH/ALG282^5.p.out",
   "$PROBLEM_LIST_PATH/ALG283^5.p.out",
   "$PROBLEM_LIST_PATH/ALG284^5.p.out",
   "$PROBLEM_LIST_PATH/ALG285^5.p.out",
   "$PROBLEM_LIST_PATH/ALG286^5.p.out",
   "$PROBLEM_LIST_PATH/ALG287^5.p.out",
   "$PROBLEM_LIST_PATH/ALG298^5.p.out",
   "$PROBLEM_LIST_PATH/CSR119^1.p.out",
   "$PROBLEM_LIST_PATH/CSR120^1.p.out",
   "$PROBLEM_LIST_PATH/CSR121^1.p.out",
   "$PROBLEM_LIST_PATH/CSR121^2.p.out",
   "$PROBLEM_LIST_PATH/CSR122^1.p.out",
   "$PROBLEM_LIST_PATH/CSR124^1.p.out",
   "$PROBLEM_LIST_PATH/CSR125^1.p.out",
   "$PROBLEM_LIST_PATH/CSR126^1.p.out",
   "$PROBLEM_LIST_PATH/CSR127^1.p.out",
   "$PROBLEM_LIST_PATH/CSR128^1.p.out",
   "$PROBLEM_LIST_PATH/CSR129^1.p.out",
   "$PROBLEM_LIST_PATH/CSR130^1.p.out",
   "$PROBLEM_LIST_PATH/CSR132^1.p.out",
   "$PROBLEM_LIST_PATH/CSR135^1.p.out",
   "$PROBLEM_LIST_PATH/CSR135^2.p.out",
   "$PROBLEM_LIST_PATH/CSR136^1.p.out",
   "$PROBLEM_LIST_PATH/CSR136^2.p.out",
   "$PROBLEM_LIST_PATH/CSR137^1.p.out",
   "$PROBLEM_LIST_PATH/CSR137^2.p.out",
   "$PROBLEM_LIST_PATH/CSR138^1.p.out",
   "$PROBLEM_LIST_PATH/CSR138^2.p.out",
   "$PROBLEM_LIST_PATH/CSR139^1.p.out",
   "$PROBLEM_LIST_PATH/CSR139^2.p.out",
   "$PROBLEM_LIST_PATH/CSR140^1.p.out",
   "$PROBLEM_LIST_PATH/CSR140^2.p.out",
   "$PROBLEM_LIST_PATH/CSR141^1.p.out",
   "$PROBLEM_LIST_PATH/CSR142^1.p.out",
   "$PROBLEM_LIST_PATH/CSR142^2.p.out",
   "$PROBLEM_LIST_PATH/CSR145^1.p.out",
   "$PROBLEM_LIST_PATH/CSR145^2.p.out",
   "$PROBLEM_LIST_PATH/CSR148^1.p.out",
   "$PROBLEM_LIST_PATH/CSR149^1.p.out",
   "$PROBLEM_LIST_PATH/CSR150^1.p.out",
   "$PROBLEM_LIST_PATH/CSR150^2.p.out",
   "$PROBLEM_LIST_PATH/CSR151^1.p.out",
   "$PROBLEM_LIST_PATH/CSR152^1.p.out",
   "$PROBLEM_LIST_PATH/CSR152^2.p.out",
   "$PROBLEM_LIST_PATH/CSR153^1.p.out",
   "$PROBLEM_LIST_PATH/DAT056^1.p.out",
   "$PROBLEM_LIST_PATH/GEG002^1.p.out",
   "$PROBLEM_LIST_PATH/GEG005^1.p.out",
   "$PROBLEM_LIST_PATH/GEG006^1.p.out",
   "$PROBLEM_LIST_PATH/GEG007^1.p.out",
   "$PROBLEM_LIST_PATH/GEG008^1.p.out",
   "$PROBLEM_LIST_PATH/GEG009^1.p.out",
   "$PROBLEM_LIST_PATH/GEG010^1.p.out",
   "$PROBLEM_LIST_PATH/GEG011^1.p.out",
   "$PROBLEM_LIST_PATH/GEG013^1.p.out",
   "$PROBLEM_LIST_PATH/GEG016^1.p.out",
   "$PROBLEM_LIST_PATH/GEG018^1.p.out",
   "$PROBLEM_LIST_PATH/GEG019^1.p.out",
   "$PROBLEM_LIST_PATH/GEG020^1.p.out",
   "$PROBLEM_LIST_PATH/GRP001^5.p.out",
   "$PROBLEM_LIST_PATH/LCL579^1.p.out",
   "$PROBLEM_LIST_PATH/LCL579^2.p.out",
   "$PROBLEM_LIST_PATH/LCL580^1.p.out",
   "$PROBLEM_LIST_PATH/LCL581^1.p.out",
   "$PROBLEM_LIST_PATH/LCL583^1.p.out",
   "$PROBLEM_LIST_PATH/LCL584^1.p.out",
   "$PROBLEM_LIST_PATH/LCL585^1.p.out",
   "$PROBLEM_LIST_PATH/LCL586^1.p.out",
   "$PROBLEM_LIST_PATH/LCL587^1.p.out",
   "$PROBLEM_LIST_PATH/LCL588^1.p.out",
   "$PROBLEM_LIST_PATH/LCL589^1.p.out",
   "$PROBLEM_LIST_PATH/LCL590^1.p.out",
   "$PROBLEM_LIST_PATH/LCL591^1.p.out",
   "$PROBLEM_LIST_PATH/LCL592^1.p.out",
   "$PROBLEM_LIST_PATH/LCL594^1.p.out",
   "$PROBLEM_LIST_PATH/LCL595^1.p.out",
   "$PROBLEM_LIST_PATH/LCL597^1.p.out",
   "$PROBLEM_LIST_PATH/LCL600^1.p.out",
   "$PROBLEM_LIST_PATH/LCL601^1.p.out",
   "$PROBLEM_LIST_PATH/LCL602^1.p.out",
   "$PROBLEM_LIST_PATH/LCL603^1.p.out",
   "$PROBLEM_LIST_PATH/LCL604^1.p.out",
   "$PROBLEM_LIST_PATH/LCL606^1.p.out",
   "$PROBLEM_LIST_PATH/LCL607^1.p.out",
   "$PROBLEM_LIST_PATH/LCL608^1.p.out",
   "$PROBLEM_LIST_PATH/LCL609^1.p.out",
   "$PROBLEM_LIST_PATH/LCL611^1.p.out",
   "$PROBLEM_LIST_PATH/LCL612^1.p.out",
   "$PROBLEM_LIST_PATH/LCL613^1.p.out",
   "$PROBLEM_LIST_PATH/LCL614^1.p.out",
   "$PROBLEM_LIST_PATH/LCL618^1.p.out",
   "$PROBLEM_LIST_PATH/LCL619^1.p.out",
   "$PROBLEM_LIST_PATH/LCL620^1.p.out",
   "$PROBLEM_LIST_PATH/LCL621^1.p.out",
   "$PROBLEM_LIST_PATH/LCL623^1.p.out",
   "$PROBLEM_LIST_PATH/LCL624^1.p.out",
   "$PROBLEM_LIST_PATH/LCL625^1.p.out",
   "$PROBLEM_LIST_PATH/LCL626^1.p.out",
   "$PROBLEM_LIST_PATH/LCL629^1.p.out",
   "$PROBLEM_LIST_PATH/LCL630^1.p.out",
   "$PROBLEM_LIST_PATH/LCL631^1.p.out",
   "$PROBLEM_LIST_PATH/LCL690^1.p.out",
   "$PROBLEM_LIST_PATH/LCL691^1.p.out",
   "$PROBLEM_LIST_PATH/LCL693^1.p.out",
   "$PROBLEM_LIST_PATH/LCL694^1.p.out",
   "$PROBLEM_LIST_PATH/LCL699^1.p.out",
   "$PROBLEM_LIST_PATH/LCL700^1.p.out",
   "$PROBLEM_LIST_PATH/LCL701^1.p.out",
   "$PROBLEM_LIST_PATH/LCL702^1.p.out",
   "$PROBLEM_LIST_PATH/LCL703^1.p.out",
   "$PROBLEM_LIST_PATH/LCL704^1.p.out",
   "$PROBLEM_LIST_PATH/LCL705^1.p.out",
   "$PROBLEM_LIST_PATH/LCL706^1.p.out",
   "$PROBLEM_LIST_PATH/LCL707^1.p.out",
   "$PROBLEM_LIST_PATH/LCL708^1.p.out",
   "$PROBLEM_LIST_PATH/LCL709^1.p.out",
   "$PROBLEM_LIST_PATH/LCL710^1.p.out",
   "$PROBLEM_LIST_PATH/LCL711^1.p.out",
   "$PROBLEM_LIST_PATH/LCL712^1.p.out",
   "$PROBLEM_LIST_PATH/LCL713^1.p.out",
   "$PROBLEM_LIST_PATH/LCL714^1.p.out",
   "$PROBLEM_LIST_PATH/LCL715^1.p.out",
   "$PROBLEM_LIST_PATH/LCL716^1.p.out",
   "$PROBLEM_LIST_PATH/LCL718^1.p.out",
   "$PROBLEM_LIST_PATH/LCL719^1.p.out",
   "$PROBLEM_LIST_PATH/LCL720^1.p.out",
   "$PROBLEM_LIST_PATH/LCL721^1.p.out",
   "$PROBLEM_LIST_PATH/LCL722^1.p.out",
   "$PROBLEM_LIST_PATH/LCL723^1.p.out",
   "$PROBLEM_LIST_PATH/LCL724^1.p.out",
   "$PROBLEM_LIST_PATH/LCL725^1.p.out",
   "$PROBLEM_LIST_PATH/LCL727^5.p.out",
   "$PROBLEM_LIST_PATH/LCL732^5.p.out",
   "$PROBLEM_LIST_PATH/LCL733^5.p.out",
   "$PROBLEM_LIST_PATH/LCL859^1.p.out",
   "$PROBLEM_LIST_PATH/LCL860^1.p.out",
   "$PROBLEM_LIST_PATH/LCL861^1.p.out",
   "$PROBLEM_LIST_PATH/LCL862^1.p.out",
   "$PROBLEM_LIST_PATH/LCL863^1.p.out",
   "$PROBLEM_LIST_PATH/LCL864^1.p.out",
   "$PROBLEM_LIST_PATH/LCL865^1.p.out",
   "$PROBLEM_LIST_PATH/LCL866^1.p.out",
   "$PROBLEM_LIST_PATH/LCL867^1.p.out",
   "$PROBLEM_LIST_PATH/LCL868^1.p.out",
   "$PROBLEM_LIST_PATH/LCL870^1.p.out",
   "$PROBLEM_LIST_PATH/LCL871^1.p.out",
   "$PROBLEM_LIST_PATH/LCL872^1.p.out",
   "$PROBLEM_LIST_PATH/LCL873^1.p.out",
   "$PROBLEM_LIST_PATH/LCL874^1.p.out",
   "$PROBLEM_LIST_PATH/LCL877^1.p.out",
   "$PROBLEM_LIST_PATH/LCL877^2.p.out",
   "$PROBLEM_LIST_PATH/LCL878^1.p.out",
   "$PROBLEM_LIST_PATH/LCL879^1.p.out",
   "$PROBLEM_LIST_PATH/LCL880^1.p.out",
   "$PROBLEM_LIST_PATH/LCL881^1.p.out",
   "$PROBLEM_LIST_PATH/NUM016^5.p.out",
   "$PROBLEM_LIST_PATH/NUM020^1.p.out",
   "$PROBLEM_LIST_PATH/NUM418^1.p.out",
   "$PROBLEM_LIST_PATH/NUM419^1.p.out",
   "$PROBLEM_LIST_PATH/NUM635^1.p.out",
   "$PROBLEM_LIST_PATH/NUM635^2.p.out",
   "$PROBLEM_LIST_PATH/NUM636^1.p.out",
   "$PROBLEM_LIST_PATH/NUM637^1.p.out",
   "$PROBLEM_LIST_PATH/NUM638^1.p.out",
   "$PROBLEM_LIST_PATH/NUM639^1.p.out",
   "$PROBLEM_LIST_PATH/NUM640^1.p.out",
   "$PROBLEM_LIST_PATH/NUM641^1.p.out",
   "$PROBLEM_LIST_PATH/NUM642^1.p.out",
   "$PROBLEM_LIST_PATH/NUM647^1.p.out",
   "$PROBLEM_LIST_PATH/NUM648^1.p.out",
   "$PROBLEM_LIST_PATH/NUM651^1.p.out",
   "$PROBLEM_LIST_PATH/NUM652^1.p.out",
   "$PROBLEM_LIST_PATH/NUM653^1.p.out",
   "$PROBLEM_LIST_PATH/NUM654^1.p.out",
   "$PROBLEM_LIST_PATH/NUM655^1.p.out",
   "$PROBLEM_LIST_PATH/NUM656^1.p.out",
   "$PROBLEM_LIST_PATH/NUM657^1.p.out",
   "$PROBLEM_LIST_PATH/NUM658^1.p.out",
   "$PROBLEM_LIST_PATH/NUM659^1.p.out",
   "$PROBLEM_LIST_PATH/NUM660^1.p.out",
   "$PROBLEM_LIST_PATH/NUM662^1.p.out",
   "$PROBLEM_LIST_PATH/NUM663^1.p.out",
   "$PROBLEM_LIST_PATH/NUM664^1.p.out",
   "$PROBLEM_LIST_PATH/NUM665^1.p.out",
   "$PROBLEM_LIST_PATH/NUM666^1.p.out",
   "$PROBLEM_LIST_PATH/NUM667^1.p.out",
   "$PROBLEM_LIST_PATH/NUM668^1.p.out",
   "$PROBLEM_LIST_PATH/NUM669^1.p.out",
   "$PROBLEM_LIST_PATH/NUM670^1.p.out",
   "$PROBLEM_LIST_PATH/NUM671^1.p.out",
   "$PROBLEM_LIST_PATH/NUM672^1.p.out",
   "$PROBLEM_LIST_PATH/NUM673^1.p.out",
   "$PROBLEM_LIST_PATH/NUM674^1.p.out",
   "$PROBLEM_LIST_PATH/NUM676^1.p.out",
   "$PROBLEM_LIST_PATH/NUM677^1.p.out",
   "$PROBLEM_LIST_PATH/NUM680^1.p.out",
   "$PROBLEM_LIST_PATH/NUM681^1.p.out",
   "$PROBLEM_LIST_PATH/NUM682^1.p.out",
   "$PROBLEM_LIST_PATH/NUM683^1.p.out",
   "$PROBLEM_LIST_PATH/NUM684^1.p.out",
   "$PROBLEM_LIST_PATH/NUM687^1.p.out",
   "$PROBLEM_LIST_PATH/NUM688^1.p.out",
   "$PROBLEM_LIST_PATH/NUM691^1.p.out",
   "$PROBLEM_LIST_PATH/NUM692^1.p.out",
   "$PROBLEM_LIST_PATH/NUM693^1.p.out",
   "$PROBLEM_LIST_PATH/NUM694^1.p.out",
   "$PROBLEM_LIST_PATH/NUM695^1.p.out",
   "$PROBLEM_LIST_PATH/NUM696^1.p.out",
   "$PROBLEM_LIST_PATH/NUM697^1.p.out",
   "$PROBLEM_LIST_PATH/NUM698^1.p.out",
   "$PROBLEM_LIST_PATH/NUM699^1.p.out",
   "$PROBLEM_LIST_PATH/NUM700^1.p.out",
   "$PROBLEM_LIST_PATH/NUM701^1.p.out",
   "$PROBLEM_LIST_PATH/NUM702^1.p.out",
   "$PROBLEM_LIST_PATH/NUM703^1.p.out",
   "$PROBLEM_LIST_PATH/NUM706^1.p.out",
   "$PROBLEM_LIST_PATH/NUM707^1.p.out",
   "$PROBLEM_LIST_PATH/NUM708^1.p.out",
   "$PROBLEM_LIST_PATH/NUM709^1.p.out",
   "$PROBLEM_LIST_PATH/NUM713^1.p.out",
   "$PROBLEM_LIST_PATH/NUM726^1.p.out",
   "$PROBLEM_LIST_PATH/NUM728^1.p.out",
   "$PROBLEM_LIST_PATH/NUM729^1.p.out",
   "$PROBLEM_LIST_PATH/NUM730^1.p.out",
   "$PROBLEM_LIST_PATH/NUM736^1.p.out",
   "$PROBLEM_LIST_PATH/NUM738^1.p.out",
   "$PROBLEM_LIST_PATH/NUM739^1.p.out",
   "$PROBLEM_LIST_PATH/NUM740^1.p.out",
   "$PROBLEM_LIST_PATH/NUM742^1.p.out",
   "$PROBLEM_LIST_PATH/NUM743^1.p.out",
   "$PROBLEM_LIST_PATH/NUM746^1.p.out",
   "$PROBLEM_LIST_PATH/NUM747^1.p.out",
   "$PROBLEM_LIST_PATH/NUM748^1.p.out",
   "$PROBLEM_LIST_PATH/NUM749^1.p.out",
   "$PROBLEM_LIST_PATH/NUM750^1.p.out",
   "$PROBLEM_LIST_PATH/NUM751^1.p.out",
   "$PROBLEM_LIST_PATH/NUM752^1.p.out",
   "$PROBLEM_LIST_PATH/NUM753^1.p.out",
   "$PROBLEM_LIST_PATH/NUM754^1.p.out",
   "$PROBLEM_LIST_PATH/NUM755^1.p.out",
   "$PROBLEM_LIST_PATH/NUM756^1.p.out",
   "$PROBLEM_LIST_PATH/NUM757^1.p.out",
   "$PROBLEM_LIST_PATH/NUM758^1.p.out",
   "$PROBLEM_LIST_PATH/NUM759^1.p.out",
   "$PROBLEM_LIST_PATH/NUM760^1.p.out",
   "$PROBLEM_LIST_PATH/NUM761^1.p.out",
   "$PROBLEM_LIST_PATH/NUM762^1.p.out",
   "$PROBLEM_LIST_PATH/NUM765^1.p.out",
   "$PROBLEM_LIST_PATH/NUM766^1.p.out",
   "$PROBLEM_LIST_PATH/NUM767^1.p.out",
   "$PROBLEM_LIST_PATH/NUM769^1.p.out",
   "$PROBLEM_LIST_PATH/NUM770^1.p.out",
   "$PROBLEM_LIST_PATH/NUM771^1.p.out",
   "$PROBLEM_LIST_PATH/NUM781^1.p.out",
   "$PROBLEM_LIST_PATH/NUM781^2.p.out",
   "$PROBLEM_LIST_PATH/NUM781^3.p.out",
   "$PROBLEM_LIST_PATH/NUM782^1.p.out",
   "$PROBLEM_LIST_PATH/NUM783^1.p.out",
   "$PROBLEM_LIST_PATH/NUM784^1.p.out",
   "$PROBLEM_LIST_PATH/NUM785^1.p.out",
   "$PROBLEM_LIST_PATH/NUM786^1.p.out",
   "$PROBLEM_LIST_PATH/NUM787^1.p.out",
   "$PROBLEM_LIST_PATH/NUM788^1.p.out",
   "$PROBLEM_LIST_PATH/NUM789^1.p.out",
   "$PROBLEM_LIST_PATH/NUM790^1.p.out",
   "$PROBLEM_LIST_PATH/NUM791^1.p.out",
   "$PROBLEM_LIST_PATH/NUM792^1.p.out",
   "$PROBLEM_LIST_PATH/NUM793^1.p.out",
   "$PROBLEM_LIST_PATH/NUM795^1.p.out",
   "$PROBLEM_LIST_PATH/NUM796^1.p.out",
   "$PROBLEM_LIST_PATH/NUM798^1.p.out",
   "$PROBLEM_LIST_PATH/NUM799^1.p.out",
   "$PROBLEM_LIST_PATH/NUM801^1.p.out",
   "$PROBLEM_LIST_PATH/NUM802^5.p.out",
   "$PROBLEM_LIST_PATH/NUM824^5.p.out",
   "$PROBLEM_LIST_PATH/NUM830^5.p.out",
   "$PROBLEM_LIST_PATH/NUM924^1.p.out",
   "$PROBLEM_LIST_PATH/NUM925^1.p.out"]

val tptp_files2 =
  ["$PROBLEM_LIST_PATH/PUZ031^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ047^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ081^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ081^2.p.out",
   "$PROBLEM_LIST_PATH/PUZ081^3.p.out",
   "$PROBLEM_LIST_PATH/PUZ082^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ083^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ084^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ085^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ086^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ087^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ087^2.p.out",
   "$PROBLEM_LIST_PATH/PUZ088^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ090^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ091^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ092^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ093^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ094^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ100^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ102^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ103^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ104^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ107^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ109^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ110^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ113^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ114^5.p.out",
   "$PROBLEM_LIST_PATH/PUZ136^1.p.out",
   "$PROBLEM_LIST_PATH/PUZ137^1.p.out",
   "$PROBLEM_LIST_PATH/QUA002^1.p.out",
   "$PROBLEM_LIST_PATH/QUA004^1.p.out",
   "$PROBLEM_LIST_PATH/SET008^5.p.out",
   "$PROBLEM_LIST_PATH/SET009^5.p.out",
   "$PROBLEM_LIST_PATH/SET010^5.p.out",
   "$PROBLEM_LIST_PATH/SET011^5.p.out",
   "$PROBLEM_LIST_PATH/SET014^4.p.out",
   "$PROBLEM_LIST_PATH/SET014^5.p.out",
   "$PROBLEM_LIST_PATH/SET017^1.p.out",
   "$PROBLEM_LIST_PATH/SET027^5.p.out",
   "$PROBLEM_LIST_PATH/SET043^5.p.out",
   "$PROBLEM_LIST_PATH/SET044^5.p.out",
   "$PROBLEM_LIST_PATH/SET045^5.p.out",
   "$PROBLEM_LIST_PATH/SET046^5.p.out",
   "$PROBLEM_LIST_PATH/SET062^5.p.out",
   "$PROBLEM_LIST_PATH/SET062^6.p.out",
   "$PROBLEM_LIST_PATH/SET063^5.p.out",
   "$PROBLEM_LIST_PATH/SET066^1.p.out",
   "$PROBLEM_LIST_PATH/SET067^1.p.out",
   "$PROBLEM_LIST_PATH/SET076^1.p.out",
   "$PROBLEM_LIST_PATH/SET086^1.p.out",
   "$PROBLEM_LIST_PATH/SET096^1.p.out",
   "$PROBLEM_LIST_PATH/SET143^3.p.out",
   "$PROBLEM_LIST_PATH/SET143^5.p.out",
   "$PROBLEM_LIST_PATH/SET144^5.p.out",
   "$PROBLEM_LIST_PATH/SET159^5.p.out",
   "$PROBLEM_LIST_PATH/SET162^5.p.out",
   "$PROBLEM_LIST_PATH/SET169^5.p.out",
   "$PROBLEM_LIST_PATH/SET171^3.p.out",
   "$PROBLEM_LIST_PATH/SET171^5.p.out",
   "$PROBLEM_LIST_PATH/SET173^5.p.out",
   "$PROBLEM_LIST_PATH/SET175^5.p.out",
   "$PROBLEM_LIST_PATH/SET183^5.p.out",
   "$PROBLEM_LIST_PATH/SET185^5.p.out",
   "$PROBLEM_LIST_PATH/SET194^5.p.out",
   "$PROBLEM_LIST_PATH/SET196^5.p.out",
   "$PROBLEM_LIST_PATH/SET199^5.p.out",
   "$PROBLEM_LIST_PATH/SET200^5.p.out",
   "$PROBLEM_LIST_PATH/SET201^5.p.out",
   "$PROBLEM_LIST_PATH/SET557^1.p.out",
   "$PROBLEM_LIST_PATH/SET580^3.p.out",
   "$PROBLEM_LIST_PATH/SET580^5.p.out",
   "$PROBLEM_LIST_PATH/SET582^5.p.out",
   "$PROBLEM_LIST_PATH/SET584^5.p.out",
   "$PROBLEM_LIST_PATH/SET585^5.p.out",
   "$PROBLEM_LIST_PATH/SET586^5.p.out",
   "$PROBLEM_LIST_PATH/SET587^5.p.out",
   "$PROBLEM_LIST_PATH/SET588^5.p.out",
   "$PROBLEM_LIST_PATH/SET589^5.p.out",
   "$PROBLEM_LIST_PATH/SET590^5.p.out",
   "$PROBLEM_LIST_PATH/SET591^5.p.out",
   "$PROBLEM_LIST_PATH/SET592^5.p.out",
   "$PROBLEM_LIST_PATH/SET593^5.p.out",
   "$PROBLEM_LIST_PATH/SET594^5.p.out",
   "$PROBLEM_LIST_PATH/SET595^5.p.out",
   "$PROBLEM_LIST_PATH/SET596^5.p.out",
   "$PROBLEM_LIST_PATH/SET597^5.p.out",
   "$PROBLEM_LIST_PATH/SET598^5.p.out",
   "$PROBLEM_LIST_PATH/SET599^5.p.out",
   "$PROBLEM_LIST_PATH/SET600^5.p.out",
   "$PROBLEM_LIST_PATH/SET601^3.p.out",
   "$PROBLEM_LIST_PATH/SET601^5.p.out",
   "$PROBLEM_LIST_PATH/SET603^5.p.out",
   "$PROBLEM_LIST_PATH/SET604^5.p.out",
   "$PROBLEM_LIST_PATH/SET605^5.p.out",
   "$PROBLEM_LIST_PATH/SET606^3.p.out",
   "$PROBLEM_LIST_PATH/SET606^5.p.out",
   "$PROBLEM_LIST_PATH/SET607^3.p.out",
   "$PROBLEM_LIST_PATH/SET607^5.p.out",
   "$PROBLEM_LIST_PATH/SET608^5.p.out",
   "$PROBLEM_LIST_PATH/SET609^3.p.out",
   "$PROBLEM_LIST_PATH/SET609^5.p.out",
   "$PROBLEM_LIST_PATH/SET610^5.p.out",
   "$PROBLEM_LIST_PATH/SET611^3.p.out",
   "$PROBLEM_LIST_PATH/SET611^5.p.out",
   "$PROBLEM_LIST_PATH/SET612^3.p.out",
   "$PROBLEM_LIST_PATH/SET612^5.p.out",
   "$PROBLEM_LIST_PATH/SET613^5.p.out",
   "$PROBLEM_LIST_PATH/SET614^3.p.out",
   "$PROBLEM_LIST_PATH/SET614^5.p.out",
   "$PROBLEM_LIST_PATH/SET615^3.p.out",
   "$PROBLEM_LIST_PATH/SET615^5.p.out",
   "$PROBLEM_LIST_PATH/SET616^5.p.out",
   "$PROBLEM_LIST_PATH/SET617^5.p.out",
   "$PROBLEM_LIST_PATH/SET618^5.p.out",
   "$PROBLEM_LIST_PATH/SET619^5.p.out",
   "$PROBLEM_LIST_PATH/SET620^5.p.out",
   "$PROBLEM_LIST_PATH/SET621^5.p.out",
   "$PROBLEM_LIST_PATH/SET622^5.p.out",
   "$PROBLEM_LIST_PATH/SET623^3.p.out",
   "$PROBLEM_LIST_PATH/SET623^5.p.out",
   "$PROBLEM_LIST_PATH/SET624^3.p.out",
   "$PROBLEM_LIST_PATH/SET624^5.p.out",
   "$PROBLEM_LIST_PATH/SET625^5.p.out",
   "$PROBLEM_LIST_PATH/SET626^5.p.out",
   "$PROBLEM_LIST_PATH/SET627^5.p.out",
   "$PROBLEM_LIST_PATH/SET628^5.p.out",
   "$PROBLEM_LIST_PATH/SET629^5.p.out",
   "$PROBLEM_LIST_PATH/SET630^3.p.out",
   "$PROBLEM_LIST_PATH/SET630^5.p.out",
   "$PROBLEM_LIST_PATH/SET631^5.p.out",
   "$PROBLEM_LIST_PATH/SET632^5.p.out",
   "$PROBLEM_LIST_PATH/SET633^5.p.out",
   "$PROBLEM_LIST_PATH/SET634^5.p.out",
   "$PROBLEM_LIST_PATH/SET635^5.p.out",
   "$PROBLEM_LIST_PATH/SET636^5.p.out",
   "$PROBLEM_LIST_PATH/SET638^5.p.out",
   "$PROBLEM_LIST_PATH/SET640^3.p.out",
   "$PROBLEM_LIST_PATH/SET646^3.p.out",
   "$PROBLEM_LIST_PATH/SET647^3.p.out",
   "$PROBLEM_LIST_PATH/SET648^3.p.out",
   "$PROBLEM_LIST_PATH/SET649^3.p.out",
   "$PROBLEM_LIST_PATH/SET651^3.p.out",
   "$PROBLEM_LIST_PATH/SET657^3.p.out",
   "$PROBLEM_LIST_PATH/SET669^3.p.out",
   "$PROBLEM_LIST_PATH/SET670^3.p.out",
   "$PROBLEM_LIST_PATH/SET671^3.p.out",
   "$PROBLEM_LIST_PATH/SET672^3.p.out",
   "$PROBLEM_LIST_PATH/SET673^3.p.out",
   "$PROBLEM_LIST_PATH/SET680^3.p.out",
   "$PROBLEM_LIST_PATH/SET683^3.p.out",
   "$PROBLEM_LIST_PATH/SET684^3.p.out",
   "$PROBLEM_LIST_PATH/SET716^4.p.out",
   "$PROBLEM_LIST_PATH/SET724^4.p.out",
   "$PROBLEM_LIST_PATH/SET741^4.p.out",
   "$PROBLEM_LIST_PATH/SET747^4.p.out",
   "$PROBLEM_LIST_PATH/SET752^4.p.out",
   "$PROBLEM_LIST_PATH/SET753^4.p.out",
   "$PROBLEM_LIST_PATH/SET764^4.p.out",
   "$PROBLEM_LIST_PATH/SEU453^1.p.out",
   "$PROBLEM_LIST_PATH/SEU454^1.p.out",
   "$PROBLEM_LIST_PATH/SEU455^1.p.out",
   "$PROBLEM_LIST_PATH/SEU456^1.p.out",
   "$PROBLEM_LIST_PATH/SEU457^1.p.out",
   "$PROBLEM_LIST_PATH/SEU458^1.p.out",
   "$PROBLEM_LIST_PATH/SEU459^1.p.out",
   "$PROBLEM_LIST_PATH/SEU460^1.p.out",
   "$PROBLEM_LIST_PATH/SEU461^1.p.out",
   "$PROBLEM_LIST_PATH/SEU462^1.p.out",
   "$PROBLEM_LIST_PATH/SEU463^1.p.out",
   "$PROBLEM_LIST_PATH/SEU464^1.p.out",
   "$PROBLEM_LIST_PATH/SEU465^1.p.out",
   "$PROBLEM_LIST_PATH/SEU467^1.p.out",
   "$PROBLEM_LIST_PATH/SEU468^1.p.out",
   "$PROBLEM_LIST_PATH/SEU469^1.p.out",
   "$PROBLEM_LIST_PATH/SEU472^1.p.out",
   "$PROBLEM_LIST_PATH/SEU474^1.p.out",
   "$PROBLEM_LIST_PATH/SEU481^1.p.out",
   "$PROBLEM_LIST_PATH/SEU484^1.p.out",
   "$PROBLEM_LIST_PATH/SEU492^1.p.out",
   "$PROBLEM_LIST_PATH/SEU493^1.p.out",
   "$PROBLEM_LIST_PATH/SEU494^1.p.out",
   "$PROBLEM_LIST_PATH/SEU495^1.p.out",
   "$PROBLEM_LIST_PATH/SEU496^1.p.out",
   "$PROBLEM_LIST_PATH/SEU497^1.p.out",
   "$PROBLEM_LIST_PATH/SEU498^1.p.out",
   "$PROBLEM_LIST_PATH/SEU499^1.p.out",
   "$PROBLEM_LIST_PATH/SEU499^2.p.out",
   "$PROBLEM_LIST_PATH/SEU500^2.p.out",
   "$PROBLEM_LIST_PATH/SEU501^1.p.out",
   "$PROBLEM_LIST_PATH/SEU501^2.p.out",
   "$PROBLEM_LIST_PATH/SEU502^1.p.out",
   "$PROBLEM_LIST_PATH/SEU502^2.p.out",
   "$PROBLEM_LIST_PATH/SEU503^1.p.out",
   "$PROBLEM_LIST_PATH/SEU503^2.p.out",
   "$PROBLEM_LIST_PATH/SEU504^1.p.out",
   "$PROBLEM_LIST_PATH/SEU504^2.p.out",
   "$PROBLEM_LIST_PATH/SEU505^1.p.out",
   "$PROBLEM_LIST_PATH/SEU505^2.p.out",
   "$PROBLEM_LIST_PATH/SEU506^1.p.out",
   "$PROBLEM_LIST_PATH/SEU506^2.p.out",
   "$PROBLEM_LIST_PATH/SEU507^1.p.out",
   "$PROBLEM_LIST_PATH/SEU508^2.p.out",
   "$PROBLEM_LIST_PATH/SEU509^1.p.out",
   "$PROBLEM_LIST_PATH/SEU509^2.p.out",
   "$PROBLEM_LIST_PATH/SEU511^1.p.out",
   "$PROBLEM_LIST_PATH/SEU511^2.p.out",
   "$PROBLEM_LIST_PATH/SEU512^1.p.out",
   "$PROBLEM_LIST_PATH/SEU512^2.p.out",
   "$PROBLEM_LIST_PATH/SEU513^1.p.out",
   "$PROBLEM_LIST_PATH/SEU513^2.p.out",
   "$PROBLEM_LIST_PATH/SEU514^1.p.out",
   "$PROBLEM_LIST_PATH/SEU514^2.p.out",
   "$PROBLEM_LIST_PATH/SEU515^1.p.out",
   "$PROBLEM_LIST_PATH/SEU515^2.p.out",
   "$PROBLEM_LIST_PATH/SEU516^1.p.out",
   "$PROBLEM_LIST_PATH/SEU516^2.p.out",
   "$PROBLEM_LIST_PATH/SEU518^1.p.out",
   "$PROBLEM_LIST_PATH/SEU518^2.p.out",
   "$PROBLEM_LIST_PATH/SEU519^1.p.out",
   "$PROBLEM_LIST_PATH/SEU519^2.p.out",
   "$PROBLEM_LIST_PATH/SEU520^1.p.out",
   "$PROBLEM_LIST_PATH/SEU521^1.p.out",
   "$PROBLEM_LIST_PATH/SEU521^2.p.out",
   "$PROBLEM_LIST_PATH/SEU522^1.p.out",
   "$PROBLEM_LIST_PATH/SEU522^2.p.out",
   "$PROBLEM_LIST_PATH/SEU523^1.p.out",
   "$PROBLEM_LIST_PATH/SEU523^2.p.out",
   "$PROBLEM_LIST_PATH/SEU524^2.p.out",
   "$PROBLEM_LIST_PATH/SEU525^1.p.out",
   "$PROBLEM_LIST_PATH/SEU525^2.p.out",
   "$PROBLEM_LIST_PATH/SEU526^1.p.out",
   "$PROBLEM_LIST_PATH/SEU526^2.p.out",
   "$PROBLEM_LIST_PATH/SEU527^1.p.out",
   "$PROBLEM_LIST_PATH/SEU527^2.p.out",
   "$PROBLEM_LIST_PATH/SEU528^1.p.out",
   "$PROBLEM_LIST_PATH/SEU528^2.p.out",
   "$PROBLEM_LIST_PATH/SEU529^1.p.out",
   "$PROBLEM_LIST_PATH/SEU529^2.p.out",
   "$PROBLEM_LIST_PATH/SEU530^1.p.out",
   "$PROBLEM_LIST_PATH/SEU530^2.p.out",
   "$PROBLEM_LIST_PATH/SEU531^1.p.out",
   "$PROBLEM_LIST_PATH/SEU531^2.p.out",
   "$PROBLEM_LIST_PATH/SEU532^1.p.out",
   "$PROBLEM_LIST_PATH/SEU532^2.p.out",
   "$PROBLEM_LIST_PATH/SEU533^1.p.out",
   "$PROBLEM_LIST_PATH/SEU533^2.p.out",
   "$PROBLEM_LIST_PATH/SEU535^1.p.out",
   "$PROBLEM_LIST_PATH/SEU535^2.p.out",
   "$PROBLEM_LIST_PATH/SEU536^1.p.out",
   "$PROBLEM_LIST_PATH/SEU536^2.p.out",
   "$PROBLEM_LIST_PATH/SEU537^1.p.out",
   "$PROBLEM_LIST_PATH/SEU537^2.p.out",
   "$PROBLEM_LIST_PATH/SEU538^1.p.out",
   "$PROBLEM_LIST_PATH/SEU538^2.p.out",
   "$PROBLEM_LIST_PATH/SEU539^1.p.out",
   "$PROBLEM_LIST_PATH/SEU539^2.p.out",
   "$PROBLEM_LIST_PATH/SEU541^1.p.out",
   "$PROBLEM_LIST_PATH/SEU541^2.p.out",
   "$PROBLEM_LIST_PATH/SEU542^1.p.out",
   "$PROBLEM_LIST_PATH/SEU543^1.p.out",
   "$PROBLEM_LIST_PATH/SEU544^1.p.out",
   "$PROBLEM_LIST_PATH/SEU544^2.p.out",
   "$PROBLEM_LIST_PATH/SEU545^1.p.out",
   "$PROBLEM_LIST_PATH/SEU545^2.p.out",
   "$PROBLEM_LIST_PATH/SEU546^1.p.out",
   "$PROBLEM_LIST_PATH/SEU546^2.p.out",
   "$PROBLEM_LIST_PATH/SEU547^1.p.out",
   "$PROBLEM_LIST_PATH/SEU547^2.p.out",
   "$PROBLEM_LIST_PATH/SEU548^1.p.out",
   "$PROBLEM_LIST_PATH/SEU548^2.p.out",
   "$PROBLEM_LIST_PATH/SEU549^1.p.out",
   "$PROBLEM_LIST_PATH/SEU549^2.p.out",
   "$PROBLEM_LIST_PATH/SEU550^2.p.out",
   "$PROBLEM_LIST_PATH/SEU551^1.p.out",
   "$PROBLEM_LIST_PATH/SEU551^2.p.out",
   "$PROBLEM_LIST_PATH/SEU551^3.p.out",
   "$PROBLEM_LIST_PATH/SEU552^1.p.out",
   "$PROBLEM_LIST_PATH/SEU552^2.p.out",
   "$PROBLEM_LIST_PATH/SEU553^1.p.out",
   "$PROBLEM_LIST_PATH/SEU553^2.p.out",
   "$PROBLEM_LIST_PATH/SEU554^1.p.out",
   "$PROBLEM_LIST_PATH/SEU555^1.p.out",
   "$PROBLEM_LIST_PATH/SEU556^1.p.out",
   "$PROBLEM_LIST_PATH/SEU557^2.p.out",
   "$PROBLEM_LIST_PATH/SEU559^1.p.out",
   "$PROBLEM_LIST_PATH/SEU559^2.p.out",
   "$PROBLEM_LIST_PATH/SEU560^1.p.out",
   "$PROBLEM_LIST_PATH/SEU560^2.p.out",
   "$PROBLEM_LIST_PATH/SEU561^1.p.out",
   "$PROBLEM_LIST_PATH/SEU561^2.p.out",
   "$PROBLEM_LIST_PATH/SEU562^1.p.out",
   "$PROBLEM_LIST_PATH/SEU562^2.p.out",
   "$PROBLEM_LIST_PATH/SEU563^2.p.out",
   "$PROBLEM_LIST_PATH/SEU564^1.p.out",
   "$PROBLEM_LIST_PATH/SEU564^2.p.out",
   "$PROBLEM_LIST_PATH/SEU565^1.p.out",
   "$PROBLEM_LIST_PATH/SEU565^2.p.out",
   "$PROBLEM_LIST_PATH/SEU566^2.p.out",
   "$PROBLEM_LIST_PATH/SEU567^2.p.out",
   "$PROBLEM_LIST_PATH/SEU568^2.p.out",
   "$PROBLEM_LIST_PATH/SEU569^2.p.out",
   "$PROBLEM_LIST_PATH/SEU570^2.p.out",
   "$PROBLEM_LIST_PATH/SEU571^2.p.out",
   "$PROBLEM_LIST_PATH/SEU572^2.p.out",
   "$PROBLEM_LIST_PATH/SEU573^2.p.out",
   "$PROBLEM_LIST_PATH/SEU574^2.p.out",
   "$PROBLEM_LIST_PATH/SEU575^2.p.out",
   "$PROBLEM_LIST_PATH/SEU576^2.p.out",
   "$PROBLEM_LIST_PATH/SEU577^2.p.out",
   "$PROBLEM_LIST_PATH/SEU578^2.p.out",
   "$PROBLEM_LIST_PATH/SEU579^2.p.out",
   "$PROBLEM_LIST_PATH/SEU581^2.p.out",
   "$PROBLEM_LIST_PATH/SEU582^2.p.out",
   "$PROBLEM_LIST_PATH/SEU584^2.p.out",
   "$PROBLEM_LIST_PATH/SEU585^2.p.out",
   "$PROBLEM_LIST_PATH/SEU586^2.p.out",
   "$PROBLEM_LIST_PATH/SEU587^2.p.out",
   "$PROBLEM_LIST_PATH/SEU588^2.p.out",
   "$PROBLEM_LIST_PATH/SEU591^2.p.out",
   "$PROBLEM_LIST_PATH/SEU592^2.p.out",
   "$PROBLEM_LIST_PATH/SEU595^2.p.out",
   "$PROBLEM_LIST_PATH/SEU596^2.p.out",
   "$PROBLEM_LIST_PATH/SEU597^2.p.out",
   "$PROBLEM_LIST_PATH/SEU598^2.p.out",
   "$PROBLEM_LIST_PATH/SEU599^2.p.out",
   "$PROBLEM_LIST_PATH/SEU602^2.p.out",
   "$PROBLEM_LIST_PATH/SEU603^2.p.out",
   "$PROBLEM_LIST_PATH/SEU604^2.p.out",
   "$PROBLEM_LIST_PATH/SEU605^2.p.out",
   "$PROBLEM_LIST_PATH/SEU606^2.p.out",
   "$PROBLEM_LIST_PATH/SEU607^2.p.out",
   "$PROBLEM_LIST_PATH/SEU608^2.p.out",
   "$PROBLEM_LIST_PATH/SEU609^2.p.out",
   "$PROBLEM_LIST_PATH/SEU610^2.p.out",
   "$PROBLEM_LIST_PATH/SEU614^2.p.out",
   "$PROBLEM_LIST_PATH/SEU615^2.p.out",
   "$PROBLEM_LIST_PATH/SEU617^2.p.out",
   "$PROBLEM_LIST_PATH/SEU618^2.p.out",
   "$PROBLEM_LIST_PATH/SEU619^2.p.out",
   "$PROBLEM_LIST_PATH/SEU620^2.p.out",
   "$PROBLEM_LIST_PATH/SEU621^2.p.out",
   "$PROBLEM_LIST_PATH/SEU622^2.p.out",
   "$PROBLEM_LIST_PATH/SEU623^2.p.out",
   "$PROBLEM_LIST_PATH/SEU625^2.p.out",
   "$PROBLEM_LIST_PATH/SEU626^2.p.out",
   "$PROBLEM_LIST_PATH/SEU627^2.p.out",
   "$PROBLEM_LIST_PATH/SEU628^2.p.out",
   "$PROBLEM_LIST_PATH/SEU629^2.p.out",
   "$PROBLEM_LIST_PATH/SEU632^2.p.out",
   "$PROBLEM_LIST_PATH/SEU633^2.p.out",
   "$PROBLEM_LIST_PATH/SEU634^2.p.out",
   "$PROBLEM_LIST_PATH/SEU635^2.p.out",
   "$PROBLEM_LIST_PATH/SEU636^2.p.out",
   "$PROBLEM_LIST_PATH/SEU641^2.p.out",
   "$PROBLEM_LIST_PATH/SEU642^2.p.out",
   "$PROBLEM_LIST_PATH/SEU644^2.p.out",
   "$PROBLEM_LIST_PATH/SEU646^2.p.out",
   "$PROBLEM_LIST_PATH/SEU647^2.p.out",
   "$PROBLEM_LIST_PATH/SEU648^2.p.out",
   "$PROBLEM_LIST_PATH/SEU649^2.p.out",
   "$PROBLEM_LIST_PATH/SEU650^2.p.out",
   "$PROBLEM_LIST_PATH/SEU651^2.p.out",
   "$PROBLEM_LIST_PATH/SEU652^2.p.out",
   "$PROBLEM_LIST_PATH/SEU653^2.p.out",
   "$PROBLEM_LIST_PATH/SEU654^2.p.out",
   "$PROBLEM_LIST_PATH/SEU657^2.p.out",
   "$PROBLEM_LIST_PATH/SEU658^2.p.out",
   "$PROBLEM_LIST_PATH/SEU659^2.p.out",
   "$PROBLEM_LIST_PATH/SEU660^2.p.out",
   "$PROBLEM_LIST_PATH/SEU661^2.p.out",
   "$PROBLEM_LIST_PATH/SEU662^2.p.out",
   "$PROBLEM_LIST_PATH/SEU663^2.p.out",
   "$PROBLEM_LIST_PATH/SEU664^2.p.out",
   "$PROBLEM_LIST_PATH/SEU672^2.p.out",
   "$PROBLEM_LIST_PATH/SEU681^2.p.out",
   "$PROBLEM_LIST_PATH/SEU682^2.p.out",
   "$PROBLEM_LIST_PATH/SEU690^2.p.out",
   "$PROBLEM_LIST_PATH/SEU692^2.p.out",
   "$PROBLEM_LIST_PATH/SEU693^2.p.out",
   "$PROBLEM_LIST_PATH/SEU694^2.p.out",
   "$PROBLEM_LIST_PATH/SEU697^2.p.out",
   "$PROBLEM_LIST_PATH/SEU700^2.p.out",
   "$PROBLEM_LIST_PATH/SEU702^2.p.out",
   "$PROBLEM_LIST_PATH/SEU706^2.p.out",
   "$PROBLEM_LIST_PATH/SEU709^2.p.out",
   "$PROBLEM_LIST_PATH/SEU711^2.p.out",
   "$PROBLEM_LIST_PATH/SEU712^2.p.out",
   "$PROBLEM_LIST_PATH/SEU713^2.p.out",
   "$PROBLEM_LIST_PATH/SEU714^2.p.out",
   "$PROBLEM_LIST_PATH/SEU715^2.p.out",
   "$PROBLEM_LIST_PATH/SEU716^2.p.out",
   "$PROBLEM_LIST_PATH/SEU717^2.p.out",
   "$PROBLEM_LIST_PATH/SEU718^2.p.out",
   "$PROBLEM_LIST_PATH/SEU719^2.p.out",
   "$PROBLEM_LIST_PATH/SEU720^2.p.out",
   "$PROBLEM_LIST_PATH/SEU721^2.p.out",
   "$PROBLEM_LIST_PATH/SEU722^2.p.out",
   "$PROBLEM_LIST_PATH/SEU723^2.p.out",
   "$PROBLEM_LIST_PATH/SEU724^2.p.out",
   "$PROBLEM_LIST_PATH/SEU725^2.p.out",
   "$PROBLEM_LIST_PATH/SEU726^2.p.out",
   "$PROBLEM_LIST_PATH/SEU727^2.p.out",
   "$PROBLEM_LIST_PATH/SEU728^2.p.out",
   "$PROBLEM_LIST_PATH/SEU729^2.p.out",
   "$PROBLEM_LIST_PATH/SEU730^2.p.out",
   "$PROBLEM_LIST_PATH/SEU731^2.p.out",
   "$PROBLEM_LIST_PATH/SEU732^2.p.out",
   "$PROBLEM_LIST_PATH/SEU733^2.p.out",
   "$PROBLEM_LIST_PATH/SEU734^2.p.out",
   "$PROBLEM_LIST_PATH/SEU735^2.p.out",
   "$PROBLEM_LIST_PATH/SEU736^2.p.out",
   "$PROBLEM_LIST_PATH/SEU737^2.p.out",
   "$PROBLEM_LIST_PATH/SEU738^2.p.out",
   "$PROBLEM_LIST_PATH/SEU739^2.p.out",
   "$PROBLEM_LIST_PATH/SEU740^2.p.out",
   "$PROBLEM_LIST_PATH/SEU741^2.p.out",
   "$PROBLEM_LIST_PATH/SEU742^2.p.out",
   "$PROBLEM_LIST_PATH/SEU743^2.p.out",
   "$PROBLEM_LIST_PATH/SEU744^2.p.out",
   "$PROBLEM_LIST_PATH/SEU745^2.p.out",
   "$PROBLEM_LIST_PATH/SEU746^2.p.out",
   "$PROBLEM_LIST_PATH/SEU747^2.p.out",
   "$PROBLEM_LIST_PATH/SEU749^2.p.out",
   "$PROBLEM_LIST_PATH/SEU750^2.p.out",
   "$PROBLEM_LIST_PATH/SEU751^2.p.out",
   "$PROBLEM_LIST_PATH/SEU752^2.p.out",
   "$PROBLEM_LIST_PATH/SEU754^2.p.out",
   "$PROBLEM_LIST_PATH/SEU755^2.p.out",
   "$PROBLEM_LIST_PATH/SEU756^2.p.out",
   "$PROBLEM_LIST_PATH/SEU758^2.p.out",
   "$PROBLEM_LIST_PATH/SEU759^2.p.out",
   "$PROBLEM_LIST_PATH/SEU760^2.p.out",
   "$PROBLEM_LIST_PATH/SEU761^2.p.out",
   "$PROBLEM_LIST_PATH/SEU762^2.p.out",
   "$PROBLEM_LIST_PATH/SEU764^2.p.out",
   "$PROBLEM_LIST_PATH/SEU768^2.p.out",
   "$PROBLEM_LIST_PATH/SEU773^2.p.out",
   "$PROBLEM_LIST_PATH/SEU774^2.p.out",
   "$PROBLEM_LIST_PATH/SEU781^2.p.out",
   "$PROBLEM_LIST_PATH/SEU782^2.p.out",
   "$PROBLEM_LIST_PATH/SEU783^2.p.out",
   "$PROBLEM_LIST_PATH/SEU784^2.p.out",
   "$PROBLEM_LIST_PATH/SEU785^2.p.out",
   "$PROBLEM_LIST_PATH/SEU786^2.p.out",
   "$PROBLEM_LIST_PATH/SEU787^2.p.out",
   "$PROBLEM_LIST_PATH/SEU789^2.p.out",
   "$PROBLEM_LIST_PATH/SEU792^2.p.out",
   "$PROBLEM_LIST_PATH/SEU799^2.p.out",
   "$PROBLEM_LIST_PATH/SEU800^2.p.out",
   "$PROBLEM_LIST_PATH/SEU803^2.p.out",
   "$PROBLEM_LIST_PATH/SEU805^2.p.out",
   "$PROBLEM_LIST_PATH/SEU806^2.p.out",
   "$PROBLEM_LIST_PATH/SEU807^2.p.out",
   "$PROBLEM_LIST_PATH/SEU808^2.p.out",
   "$PROBLEM_LIST_PATH/SEU809^2.p.out",
   "$PROBLEM_LIST_PATH/SEU810^2.p.out",
   "$PROBLEM_LIST_PATH/SEU811^2.p.out",
   "$PROBLEM_LIST_PATH/SEU812^2.p.out",
   "$PROBLEM_LIST_PATH/SEU813^2.p.out",
   "$PROBLEM_LIST_PATH/SEU814^2.p.out",
   "$PROBLEM_LIST_PATH/SEU815^2.p.out",
   "$PROBLEM_LIST_PATH/SEU816^2.p.out",
   "$PROBLEM_LIST_PATH/SEU817^2.p.out",
   "$PROBLEM_LIST_PATH/SEU819^2.p.out",
   "$PROBLEM_LIST_PATH/SEU820^2.p.out",
   "$PROBLEM_LIST_PATH/SEU821^2.p.out",
   "$PROBLEM_LIST_PATH/SEU822^2.p.out",
   "$PROBLEM_LIST_PATH/SEU826^1.p.out",
   "$PROBLEM_LIST_PATH/SEU827^1.p.out",
   "$PROBLEM_LIST_PATH/SEU828^1.p.out",
   "$PROBLEM_LIST_PATH/SEU829^1.p.out",
   "$PROBLEM_LIST_PATH/SEU831^5.p.out",
   "$PROBLEM_LIST_PATH/SEU832^5.p.out",
   "$PROBLEM_LIST_PATH/SEU833^5.p.out",
   "$PROBLEM_LIST_PATH/SEU834^5.p.out",
   "$PROBLEM_LIST_PATH/SEU836^5.p.out",
   "$PROBLEM_LIST_PATH/SEU839^5.p.out",
   "$PROBLEM_LIST_PATH/SEU841^5.p.out",
   "$PROBLEM_LIST_PATH/SEU842^5.p.out",
   "$PROBLEM_LIST_PATH/SEU843^5.p.out",
   "$PROBLEM_LIST_PATH/SEU844^5.p.out",
   "$PROBLEM_LIST_PATH/SEU845^5.p.out",
   "$PROBLEM_LIST_PATH/SEU846^5.p.out",
   "$PROBLEM_LIST_PATH/SEU847^5.p.out",
   "$PROBLEM_LIST_PATH/SEU848^5.p.out",
   "$PROBLEM_LIST_PATH/SEU849^5.p.out",
   "$PROBLEM_LIST_PATH/SEU850^5.p.out",
   "$PROBLEM_LIST_PATH/SEU851^5.p.out",
   "$PROBLEM_LIST_PATH/SEU852^5.p.out",
   "$PROBLEM_LIST_PATH/SEU853^5.p.out",
   "$PROBLEM_LIST_PATH/SEU854^5.p.out",
   "$PROBLEM_LIST_PATH/SEU855^5.p.out",
   "$PROBLEM_LIST_PATH/SEU856^5.p.out",
   "$PROBLEM_LIST_PATH/SEU857^5.p.out",
   "$PROBLEM_LIST_PATH/SEU858^5.p.out",
   "$PROBLEM_LIST_PATH/SEU861^5.p.out",
   "$PROBLEM_LIST_PATH/SEU882^5.p.out",
   "$PROBLEM_LIST_PATH/SEU883^5.p.out",
   "$PROBLEM_LIST_PATH/SEU884^5.p.out",
   "$PROBLEM_LIST_PATH/SEU885^5.p.out",
   "$PROBLEM_LIST_PATH/SEU886^5.p.out",
   "$PROBLEM_LIST_PATH/SEU887^5.p.out",
   "$PROBLEM_LIST_PATH/SEU888^5.p.out",
   "$PROBLEM_LIST_PATH/SEU889^5.p.out",
   "$PROBLEM_LIST_PATH/SEU890^5.p.out",
   "$PROBLEM_LIST_PATH/SEU891^5.p.out",
   "$PROBLEM_LIST_PATH/SEU893^5.p.out",
   "$PROBLEM_LIST_PATH/SEU894^5.p.out",
   "$PROBLEM_LIST_PATH/SEU895^5.p.out",
   "$PROBLEM_LIST_PATH/SEU896^5.p.out",
   "$PROBLEM_LIST_PATH/SEU898^5.p.out",
   "$PROBLEM_LIST_PATH/SEU899^5.p.out",
   "$PROBLEM_LIST_PATH/SEU901^5.p.out",
   "$PROBLEM_LIST_PATH/SEU902^5.p.out",
   "$PROBLEM_LIST_PATH/SEU903^5.p.out",
   "$PROBLEM_LIST_PATH/SEU904^5.p.out",
   "$PROBLEM_LIST_PATH/SEU905^5.p.out",
   "$PROBLEM_LIST_PATH/SEU908^5.p.out",
   "$PROBLEM_LIST_PATH/SEU917^5.p.out",
   "$PROBLEM_LIST_PATH/SEU918^5.p.out",
   "$PROBLEM_LIST_PATH/SEU919^5.p.out",
   "$PROBLEM_LIST_PATH/SEU920^5.p.out",
   "$PROBLEM_LIST_PATH/SEU921^5.p.out",
   "$PROBLEM_LIST_PATH/SEU922^5.p.out",
   "$PROBLEM_LIST_PATH/SEU923^5.p.out",
   "$PROBLEM_LIST_PATH/SEU924^5.p.out",
   "$PROBLEM_LIST_PATH/SEU925^5.p.out",
   "$PROBLEM_LIST_PATH/SEU926^5.p.out",
   "$PROBLEM_LIST_PATH/SEU927^5.p.out",
   "$PROBLEM_LIST_PATH/SEU928^5.p.out",
   "$PROBLEM_LIST_PATH/SEU930^5.p.out",
   "$PROBLEM_LIST_PATH/SEU931^5.p.out",
   "$PROBLEM_LIST_PATH/SEU932^5.p.out",
   "$PROBLEM_LIST_PATH/SEU934^5.p.out",
   "$PROBLEM_LIST_PATH/SEU935^5.p.out",
   "$PROBLEM_LIST_PATH/SEU936^5.p.out",
   "$PROBLEM_LIST_PATH/SEU937^5.p.out",
   "$PROBLEM_LIST_PATH/SEU941^5.p.out",
   "$PROBLEM_LIST_PATH/SEU945^5.p.out",
   "$PROBLEM_LIST_PATH/SEU956^5.p.out",
   "$PROBLEM_LIST_PATH/SEU957^5.p.out",
   "$PROBLEM_LIST_PATH/SEU961^5.p.out",
   "$PROBLEM_LIST_PATH/SEU967^5.p.out",
   "$PROBLEM_LIST_PATH/SEU970^5.p.out",
   "$PROBLEM_LIST_PATH/SEU974^5.p.out",
   "$PROBLEM_LIST_PATH/SEU975^5.p.out",
   "$PROBLEM_LIST_PATH/SEU995^5.p.out",
   "$PROBLEM_LIST_PATH/SEU996^5.p.out",
   "$PROBLEM_LIST_PATH/SEU997^5.p.out",
   "$PROBLEM_LIST_PATH/SEU998^5.p.out",
   "$PROBLEM_LIST_PATH/SEU999^5.p.out",
   "$PROBLEM_LIST_PATH/SEV000^5.p.out",
   "$PROBLEM_LIST_PATH/SEV001^5.p.out",
   "$PROBLEM_LIST_PATH/SEV002^5.p.out",
   "$PROBLEM_LIST_PATH/SEV006^5.p.out",
   "$PROBLEM_LIST_PATH/SEV008^5.p.out",
   "$PROBLEM_LIST_PATH/SEV009^5.p.out",
   "$PROBLEM_LIST_PATH/SEV012^5.p.out",
   "$PROBLEM_LIST_PATH/SEV013^5.p.out",
   "$PROBLEM_LIST_PATH/SEV014^5.p.out",
   "$PROBLEM_LIST_PATH/SEV015^5.p.out",
   "$PROBLEM_LIST_PATH/SEV017^5.p.out",
   "$PROBLEM_LIST_PATH/SEV019^5.p.out",
   "$PROBLEM_LIST_PATH/SEV028^5.p.out",
   "$PROBLEM_LIST_PATH/SEV031^5.p.out",
   "$PROBLEM_LIST_PATH/SEV034^5.p.out",
   "$PROBLEM_LIST_PATH/SEV037^5.p.out",
   "$PROBLEM_LIST_PATH/SEV041^5.p.out",
   "$PROBLEM_LIST_PATH/SEV043^5.p.out",
   "$PROBLEM_LIST_PATH/SEV044^5.p.out",
   "$PROBLEM_LIST_PATH/SEV045^5.p.out",
   "$PROBLEM_LIST_PATH/SEV046^5.p.out",
   "$PROBLEM_LIST_PATH/SEV047^5.p.out",
   "$PROBLEM_LIST_PATH/SEV048^5.p.out",
   "$PROBLEM_LIST_PATH/SEV049^5.p.out",
   "$PROBLEM_LIST_PATH/SEV051^5.p.out",
   "$PROBLEM_LIST_PATH/SEV052^5.p.out",
   "$PROBLEM_LIST_PATH/SEV053^5.p.out",
   "$PROBLEM_LIST_PATH/SEV054^5.p.out",
   "$PROBLEM_LIST_PATH/SEV055^5.p.out",
   "$PROBLEM_LIST_PATH/SEV058^5.p.out",
   "$PROBLEM_LIST_PATH/SEV059^5.p.out",
   "$PROBLEM_LIST_PATH/SEV060^5.p.out",
   "$PROBLEM_LIST_PATH/SEV061^5.p.out",
   "$PROBLEM_LIST_PATH/SEV062^5.p.out",
   "$PROBLEM_LIST_PATH/SEV063^5.p.out",
   "$PROBLEM_LIST_PATH/SEV065^5.p.out",
   "$PROBLEM_LIST_PATH/SEV067^5.p.out",
   "$PROBLEM_LIST_PATH/SEV070^5.p.out",
   "$PROBLEM_LIST_PATH/SEV076^5.p.out",
   "$PROBLEM_LIST_PATH/SEV079^5.p.out",
   "$PROBLEM_LIST_PATH/SEV081^5.p.out",
   "$PROBLEM_LIST_PATH/SEV082^5.p.out",
   "$PROBLEM_LIST_PATH/SEV083^5.p.out",
   "$PROBLEM_LIST_PATH/SEV084^5.p.out",
   "$PROBLEM_LIST_PATH/SEV088^5.p.out",
   "$PROBLEM_LIST_PATH/SEV089^5.p.out",
   "$PROBLEM_LIST_PATH/SEV091^5.p.out",
   "$PROBLEM_LIST_PATH/SEV094^5.p.out",
   "$PROBLEM_LIST_PATH/SEV096^5.p.out",
   "$PROBLEM_LIST_PATH/SEV097^5.p.out",
   "$PROBLEM_LIST_PATH/SEV104^5.p.out",
   "$PROBLEM_LIST_PATH/SEV107^5.p.out",
   "$PROBLEM_LIST_PATH/SEV109^5.p.out",
   "$PROBLEM_LIST_PATH/SEV116^5.p.out",
   "$PROBLEM_LIST_PATH/SEV120^5.p.out",
   "$PROBLEM_LIST_PATH/SEV121^5.p.out",
   "$PROBLEM_LIST_PATH/SEV122^5.p.out",
   "$PROBLEM_LIST_PATH/SEV123^5.p.out",
   "$PROBLEM_LIST_PATH/SEV124^5.p.out",
   "$PROBLEM_LIST_PATH/SEV126^5.p.out",
   "$PROBLEM_LIST_PATH/SEV127^5.p.out",
   "$PROBLEM_LIST_PATH/SEV129^5.p.out",
   "$PROBLEM_LIST_PATH/SEV131^5.p.out",
   "$PROBLEM_LIST_PATH/SEV134^5.p.out",
   "$PROBLEM_LIST_PATH/SEV135^5.p.out",
   "$PROBLEM_LIST_PATH/SEV136^5.p.out",
   "$PROBLEM_LIST_PATH/SEV137^5.p.out",
   "$PROBLEM_LIST_PATH/SEV138^5.p.out",
   "$PROBLEM_LIST_PATH/SEV146^5.p.out",
   "$PROBLEM_LIST_PATH/SEV149^5.p.out",
   "$PROBLEM_LIST_PATH/SEV159^5.p.out",
   "$PROBLEM_LIST_PATH/SEV160^5.p.out",
   "$PROBLEM_LIST_PATH/SEV161^5.p.out",
   "$PROBLEM_LIST_PATH/SEV162^5.p.out",
   "$PROBLEM_LIST_PATH/SEV163^5.p.out",
   "$PROBLEM_LIST_PATH/SEV164^5.p.out",
   "$PROBLEM_LIST_PATH/SEV166^5.p.out",
   "$PROBLEM_LIST_PATH/SEV168^5.p.out",
   "$PROBLEM_LIST_PATH/SEV169^5.p.out",
   "$PROBLEM_LIST_PATH/SEV176^5.p.out",
   "$PROBLEM_LIST_PATH/SEV177^5.p.out",
   "$PROBLEM_LIST_PATH/SEV185^5.p.out",
   "$PROBLEM_LIST_PATH/SEV186^5.p.out",
   "$PROBLEM_LIST_PATH/SEV187^5.p.out",
   "$PROBLEM_LIST_PATH/SEV188^5.p.out",
   "$PROBLEM_LIST_PATH/SEV191^5.p.out",
   "$PROBLEM_LIST_PATH/SEV194^5.p.out",
   "$PROBLEM_LIST_PATH/SEV196^5.p.out",
   "$PROBLEM_LIST_PATH/SEV197^5.p.out",
   "$PROBLEM_LIST_PATH/SEV200^5.p.out",
   "$PROBLEM_LIST_PATH/SEV214^5.p.out",
   "$PROBLEM_LIST_PATH/SEV218^5.p.out",
   "$PROBLEM_LIST_PATH/SEV220^5.p.out",
   "$PROBLEM_LIST_PATH/SEV225^5.p.out",
   "$PROBLEM_LIST_PATH/SEV227^5.p.out",
   "$PROBLEM_LIST_PATH/SEV228^5.p.out",
   "$PROBLEM_LIST_PATH/SEV229^5.p.out",
   "$PROBLEM_LIST_PATH/SEV230^5.p.out",
   "$PROBLEM_LIST_PATH/SEV231^5.p.out",
   "$PROBLEM_LIST_PATH/SEV232^5.p.out",
   "$PROBLEM_LIST_PATH/SEV233^5.p.out",
   "$PROBLEM_LIST_PATH/SEV235^5.p.out",
   "$PROBLEM_LIST_PATH/SEV239^5.p.out",
   "$PROBLEM_LIST_PATH/SEV240^5.p.out",
   "$PROBLEM_LIST_PATH/SEV241^5.p.out",
   "$PROBLEM_LIST_PATH/SEV245^5.p.out",
   "$PROBLEM_LIST_PATH/SEV245^6.p.out",
   "$PROBLEM_LIST_PATH/SEV258^5.p.out",
   "$PROBLEM_LIST_PATH/SEV259^5.p.out",
   "$PROBLEM_LIST_PATH/SEV261^5.p.out",
   "$PROBLEM_LIST_PATH/SEV272^5.p.out",
   "$PROBLEM_LIST_PATH/SEV273^5.p.out",
   "$PROBLEM_LIST_PATH/SEV282^5.p.out",
   "$PROBLEM_LIST_PATH/SEV285^5.p.out",
   "$PROBLEM_LIST_PATH/SEV286^5.p.out",
   "$PROBLEM_LIST_PATH/SEV288^5.p.out",
   "$PROBLEM_LIST_PATH/SEV290^5.p.out",
   "$PROBLEM_LIST_PATH/SEV293^5.p.out",
   "$PROBLEM_LIST_PATH/SEV300^5.p.out",
   "$PROBLEM_LIST_PATH/SEV310^5.p.out",
   "$PROBLEM_LIST_PATH/SEV311^5.p.out",
   "$PROBLEM_LIST_PATH/SEV382^5.p.out",
   "$PROBLEM_LIST_PATH/SEV383^5.p.out",
   "$PROBLEM_LIST_PATH/SEV384^5.p.out",
   "$PROBLEM_LIST_PATH/SEV385^5.p.out",
   "$PROBLEM_LIST_PATH/SEV386^5.p.out",
   "$PROBLEM_LIST_PATH/SEV387^5.p.out",
   "$PROBLEM_LIST_PATH/SEV388^5.p.out",
   "$PROBLEM_LIST_PATH/SEV389^5.p.out",
   "$PROBLEM_LIST_PATH/SEV390^5.p.out",
   "$PROBLEM_LIST_PATH/SEV391^5.p.out",
   "$PROBLEM_LIST_PATH/SEV392^5.p.out",
   "$PROBLEM_LIST_PATH/SEV393^5.p.out",
   "$PROBLEM_LIST_PATH/SEV394^5.p.out",
   "$PROBLEM_LIST_PATH/SEV396^5.p.out",
   "$PROBLEM_LIST_PATH/SEV397^5.p.out",
   "$PROBLEM_LIST_PATH/SEV398^5.p.out",
   "$PROBLEM_LIST_PATH/SEV401^5.p.out",
   "$PROBLEM_LIST_PATH/SEV405^5.p.out",
   "$PROBLEM_LIST_PATH/SEV406^5.p.out",
   "$PROBLEM_LIST_PATH/SEV408^5.p.out",
   "$PROBLEM_LIST_PATH/SEV409^5.p.out",
   "$PROBLEM_LIST_PATH/SEV411^5.p.out",
   "$PROBLEM_LIST_PATH/SEV412^5.p.out",
   "$PROBLEM_LIST_PATH/SEV413^5.p.out",
   "$PROBLEM_LIST_PATH/SEV416^5.p.out",
   "$PROBLEM_LIST_PATH/SEV417^5.p.out",
   "$PROBLEM_LIST_PATH/SEV420^1.p.out",
   "$PROBLEM_LIST_PATH/SEV427^1.p.out",
   "$PROBLEM_LIST_PATH/SEV430^1.p.out",
   "$PROBLEM_LIST_PATH/SEV432^1.p.out",
   "$PROBLEM_LIST_PATH/SEV433^1.p.out",
   "$PROBLEM_LIST_PATH/SEV434^1.p.out",
   "$PROBLEM_LIST_PATH/SWV425^2.p.out",
   "$PROBLEM_LIST_PATH/SWV426^2.p.out",
   "$PROBLEM_LIST_PATH/SWV426^4.p.out",
   "$PROBLEM_LIST_PATH/SWV427^2.p.out",
   "$PROBLEM_LIST_PATH/SWV428^2.p.out",
   "$PROBLEM_LIST_PATH/SWV429^1.p.out",
   "$PROBLEM_LIST_PATH/SWV429^2.p.out",
   "$PROBLEM_LIST_PATH/SWV430^2.p.out",
   "$PROBLEM_LIST_PATH/SWV431^2.p.out",
   "$PROBLEM_LIST_PATH/SWV432^2.p.out",
   "$PROBLEM_LIST_PATH/SWV433^2.p.out",
   "$PROBLEM_LIST_PATH/SWV434^4.p.out",
   "$PROBLEM_LIST_PATH/SWV435^3.p.out",
   "$PROBLEM_LIST_PATH/SWV435^4.p.out",
   "$PROBLEM_LIST_PATH/SWV436^4.p.out",
   "$PROBLEM_LIST_PATH/SWV441^1.p.out",
   "$PROBLEM_LIST_PATH/SWV442^1.p.out",
   "$PROBLEM_LIST_PATH/SWV443^1.p.out",
   "$PROBLEM_LIST_PATH/SWV444^1.p.out",
   "$PROBLEM_LIST_PATH/SWV445^1.p.out",
   "$PROBLEM_LIST_PATH/SWV446^1.p.out",
   "$PROBLEM_LIST_PATH/SWV447^1.p.out",
   "$PROBLEM_LIST_PATH/SWW469^1.p.out",
   "$PROBLEM_LIST_PATH/SWW478^1.p.out"]

(* "$PROBLEM_LIST_PATH/SYN000^1.p.out", *)

val tptp_files3 =
  ["$PROBLEM_LIST_PATH/SYN036^5.p.out",
   "$PROBLEM_LIST_PATH/SYN041^4.p.out",
   "$PROBLEM_LIST_PATH/SYN044^4.p.out",
   "$PROBLEM_LIST_PATH/SYN045^4.p.out",
   "$PROBLEM_LIST_PATH/SYN049^5.p.out",
   "$PROBLEM_LIST_PATH/SYN051^5.p.out",
   "$PROBLEM_LIST_PATH/SYN055^5.p.out",
   "$PROBLEM_LIST_PATH/SYN056^5.p.out",
   "$PROBLEM_LIST_PATH/SYN057^5.p.out",
   "$PROBLEM_LIST_PATH/SYN058^5.p.out",
   "$PROBLEM_LIST_PATH/SYN059^5.p.out",
   "$PROBLEM_LIST_PATH/SYN064^5.p.out",
   "$PROBLEM_LIST_PATH/SYN355^5.p.out",
   "$PROBLEM_LIST_PATH/SYN356^5.p.out",
   "$PROBLEM_LIST_PATH/SYN357^5.p.out",
   "$PROBLEM_LIST_PATH/SYN358^5.p.out",
   "$PROBLEM_LIST_PATH/SYN360^5.p.out",
   "$PROBLEM_LIST_PATH/SYN361^5.p.out",
   "$PROBLEM_LIST_PATH/SYN364^5.p.out",
   "$PROBLEM_LIST_PATH/SYN365^5.p.out",
   "$PROBLEM_LIST_PATH/SYN374^5.p.out",
   "$PROBLEM_LIST_PATH/SYN375^5.p.out",
   "$PROBLEM_LIST_PATH/SYN377^5.p.out",
   "$PROBLEM_LIST_PATH/SYN381^5.p.out",
   "$PROBLEM_LIST_PATH/SYN382^5.p.out",
   "$PROBLEM_LIST_PATH/SYN386^5.p.out",
   "$PROBLEM_LIST_PATH/SYN390^4.p.out",
   "$PROBLEM_LIST_PATH/SYN391^4.p.out",
   "$PROBLEM_LIST_PATH/SYN393^4.002.p.out",
   "$PROBLEM_LIST_PATH/SYN731^5.p.out",
   "$PROBLEM_LIST_PATH/SYN732^5.p.out",
   "$PROBLEM_LIST_PATH/SYN915^4.p.out",
   "$PROBLEM_LIST_PATH/SYN978^4.p.out",
   "$PROBLEM_LIST_PATH/SYN983^1.p.out",
   "$PROBLEM_LIST_PATH/SYN984^1.p.out",
   "$PROBLEM_LIST_PATH/SYN987^2.p.out",
   "$PROBLEM_LIST_PATH/SYN988^2.p.out",
   "$PROBLEM_LIST_PATH/SYN989^1.p.out",
   "$PROBLEM_LIST_PATH/SYN989^3.p.out",
   "$PROBLEM_LIST_PATH/SYN991^1.p.out",
   "$PROBLEM_LIST_PATH/SYN992^1.p.out",
   "$PROBLEM_LIST_PATH/SYN996^1.p.out",
   "$PROBLEM_LIST_PATH/SYN998^1.p.out",
   "$PROBLEM_LIST_PATH/SYN999^1.p.out",
   "$PROBLEM_LIST_PATH/SYO001^1.p.out",
   "$PROBLEM_LIST_PATH/SYO002^1.p.out",
   "$PROBLEM_LIST_PATH/SYO003^1.p.out",
   "$PROBLEM_LIST_PATH/SYO004^1.p.out",
   "$PROBLEM_LIST_PATH/SYO005^1.p.out",
   "$PROBLEM_LIST_PATH/SYO006^1.p.out",
   "$PROBLEM_LIST_PATH/SYO007^1.p.out",
   "$PROBLEM_LIST_PATH/SYO008^1.p.out",
   "$PROBLEM_LIST_PATH/SYO009^1.p.out",
   "$PROBLEM_LIST_PATH/SYO010^1.p.out",
   "$PROBLEM_LIST_PATH/SYO011^1.p.out",
   "$PROBLEM_LIST_PATH/SYO012^1.p.out",
   "$PROBLEM_LIST_PATH/SYO013^1.p.out",
   "$PROBLEM_LIST_PATH/SYO015^1.p.out",
   "$PROBLEM_LIST_PATH/SYO017^1.p.out",
   "$PROBLEM_LIST_PATH/SYO018^1.p.out",
   "$PROBLEM_LIST_PATH/SYO019^1.p.out",
   "$PROBLEM_LIST_PATH/SYO020^1.p.out",
   "$PROBLEM_LIST_PATH/SYO021^1.p.out",
   "$PROBLEM_LIST_PATH/SYO022^1.p.out",
   "$PROBLEM_LIST_PATH/SYO023^1.p.out",
   "$PROBLEM_LIST_PATH/SYO024^1.p.out",
   "$PROBLEM_LIST_PATH/SYO025^1.p.out",
   "$PROBLEM_LIST_PATH/SYO026^1.p.out",
   "$PROBLEM_LIST_PATH/SYO027^1.p.out",
   "$PROBLEM_LIST_PATH/SYO028^1.p.out",
   "$PROBLEM_LIST_PATH/SYO029^1.p.out",
   "$PROBLEM_LIST_PATH/SYO030^1.p.out",
   "$PROBLEM_LIST_PATH/SYO031^1.p.out",
   "$PROBLEM_LIST_PATH/SYO032^1.p.out",
   "$PROBLEM_LIST_PATH/SYO034^1.p.out",
   "$PROBLEM_LIST_PATH/SYO035^1.p.out",
   "$PROBLEM_LIST_PATH/SYO038^1.003.003.p.out",
   "$PROBLEM_LIST_PATH/SYO039^1.p.out",
   "$PROBLEM_LIST_PATH/SYO039^2.p.out",
   "$PROBLEM_LIST_PATH/SYO040^1.p.out",
   "$PROBLEM_LIST_PATH/SYO040^2.p.out",
   "$PROBLEM_LIST_PATH/SYO042^1.p.out",
   "$PROBLEM_LIST_PATH/SYO042^2.p.out",
   "$PROBLEM_LIST_PATH/SYO043^1.p.out",
   "$PROBLEM_LIST_PATH/SYO044^1.p.out",
   "$PROBLEM_LIST_PATH/SYO045^1.p.out",
   "$PROBLEM_LIST_PATH/SYO046^1.p.out",
   "$PROBLEM_LIST_PATH/SYO047^1.p.out",
   "$PROBLEM_LIST_PATH/SYO048^1.p.out",
   "$PROBLEM_LIST_PATH/SYO049^1.p.out",
   "$PROBLEM_LIST_PATH/SYO050^2.p.out",
   "$PROBLEM_LIST_PATH/SYO052^2.p.out",
   "$PROBLEM_LIST_PATH/SYO053^2.p.out",
   "$PROBLEM_LIST_PATH/SYO057^2.p.out",
   "$PROBLEM_LIST_PATH/SYO058^4.p.out",
   "$PROBLEM_LIST_PATH/SYO059^4.p.out",
   "$PROBLEM_LIST_PATH/SYO060^4.p.out",
   "$PROBLEM_LIST_PATH/SYO061^4.p.out",
   "$PROBLEM_LIST_PATH/SYO062^4.002.p.out",
   "$PROBLEM_LIST_PATH/SYO062^4.003.p.out",
   "$PROBLEM_LIST_PATH/SYO064^4.001.p.out",
   "$PROBLEM_LIST_PATH/SYO064^4.002.p.out",
   "$PROBLEM_LIST_PATH/SYO066^4.001.p.out",
   "$PROBLEM_LIST_PATH/SYO066^4.002.p.out",
   "$PROBLEM_LIST_PATH/SYO067^4.001.p.out",
   "$PROBLEM_LIST_PATH/SYO067^4.002.p.out",
   "$PROBLEM_LIST_PATH/SYO068^4.001.p.out",
   "$PROBLEM_LIST_PATH/SYO068^4.005.p.out",
   "$PROBLEM_LIST_PATH/SYO068^4.010.p.out",
   "$PROBLEM_LIST_PATH/SYO068^4.020.p.out",
   "$PROBLEM_LIST_PATH/SYO069^4.001.p.out",
   "$PROBLEM_LIST_PATH/SYO069^4.002.p.out",
   "$PROBLEM_LIST_PATH/SYO069^4.003.p.out",
   "$PROBLEM_LIST_PATH/SYO069^4.004.p.out",
   "$PROBLEM_LIST_PATH/SYO076^5.p.out",
   "$PROBLEM_LIST_PATH/SYO077^5.p.out",
   "$PROBLEM_LIST_PATH/SYO078^5.p.out",
   "$PROBLEM_LIST_PATH/SYO079^5.p.out",
   "$PROBLEM_LIST_PATH/SYO080^5.p.out",
   "$PROBLEM_LIST_PATH/SYO081^5.p.out",
   "$PROBLEM_LIST_PATH/SYO082^5.p.out",
   "$PROBLEM_LIST_PATH/SYO083^5.p.out",
   "$PROBLEM_LIST_PATH/SYO084^5.p.out",
   "$PROBLEM_LIST_PATH/SYO085^5.p.out",
   "$PROBLEM_LIST_PATH/SYO086^5.p.out",
   "$PROBLEM_LIST_PATH/SYO087^5.p.out",
   "$PROBLEM_LIST_PATH/SYO088^5.p.out",
   "$PROBLEM_LIST_PATH/SYO089^5.p.out",
   "$PROBLEM_LIST_PATH/SYO090^5.p.out",
   "$PROBLEM_LIST_PATH/SYO091^5.p.out",
   "$PROBLEM_LIST_PATH/SYO092^5.p.out",
   "$PROBLEM_LIST_PATH/SYO093^5.p.out",
   "$PROBLEM_LIST_PATH/SYO094^5.p.out",
   "$PROBLEM_LIST_PATH/SYO095^5.p.out",
   "$PROBLEM_LIST_PATH/SYO096^5.p.out",
   "$PROBLEM_LIST_PATH/SYO098^5.p.out",
   "$PROBLEM_LIST_PATH/SYO099^5.p.out",
   "$PROBLEM_LIST_PATH/SYO101^5.p.out",
   "$PROBLEM_LIST_PATH/SYO102^5.p.out",
   "$PROBLEM_LIST_PATH/SYO103^5.p.out",
   "$PROBLEM_LIST_PATH/SYO104^5.p.out",
   "$PROBLEM_LIST_PATH/SYO105^5.p.out",
   "$PROBLEM_LIST_PATH/SYO107^5.p.out",
   "$PROBLEM_LIST_PATH/SYO108^5.p.out",
   "$PROBLEM_LIST_PATH/SYO109^5.p.out",
   "$PROBLEM_LIST_PATH/SYO111^5.p.out",
   "$PROBLEM_LIST_PATH/SYO112^5.p.out",
   "$PROBLEM_LIST_PATH/SYO113^5.p.out",
   "$PROBLEM_LIST_PATH/SYO114^5.p.out",
   "$PROBLEM_LIST_PATH/SYO118^5.p.out",
   "$PROBLEM_LIST_PATH/SYO119^5.p.out",
   "$PROBLEM_LIST_PATH/SYO120^5.p.out",
   "$PROBLEM_LIST_PATH/SYO123^5.p.out",
   "$PROBLEM_LIST_PATH/SYO124^5.p.out",
   "$PROBLEM_LIST_PATH/SYO125^5.p.out",
   "$PROBLEM_LIST_PATH/SYO128^5.p.out",
   "$PROBLEM_LIST_PATH/SYO129^5.p.out",
   "$PROBLEM_LIST_PATH/SYO131^5.p.out",
   "$PROBLEM_LIST_PATH/SYO132^5.p.out",
   "$PROBLEM_LIST_PATH/SYO133^5.p.out",
   "$PROBLEM_LIST_PATH/SYO134^5.p.out",
   "$PROBLEM_LIST_PATH/SYO135^5.p.out",
   "$PROBLEM_LIST_PATH/SYO136^5.p.out",
   "$PROBLEM_LIST_PATH/SYO139^5.p.out",
   "$PROBLEM_LIST_PATH/SYO140^5.p.out",
   "$PROBLEM_LIST_PATH/SYO141^5.p.out",
   "$PROBLEM_LIST_PATH/SYO142^5.p.out",
   "$PROBLEM_LIST_PATH/SYO143^5.p.out",
   "$PROBLEM_LIST_PATH/SYO145^5.p.out",
   "$PROBLEM_LIST_PATH/SYO146^5.p.out",
   "$PROBLEM_LIST_PATH/SYO147^5.p.out",
   "$PROBLEM_LIST_PATH/SYO148^5.p.out",
   "$PROBLEM_LIST_PATH/SYO149^5.p.out",
   "$PROBLEM_LIST_PATH/SYO154^5.p.out",
   "$PROBLEM_LIST_PATH/SYO159^5.p.out",
   "$PROBLEM_LIST_PATH/SYO160^5.p.out",
   "$PROBLEM_LIST_PATH/SYO161^5.p.out",
   "$PROBLEM_LIST_PATH/SYO169^5.p.out",
   "$PROBLEM_LIST_PATH/SYO170^5.p.out",
   "$PROBLEM_LIST_PATH/SYO171^5.p.out",
   "$PROBLEM_LIST_PATH/SYO173^5.p.out",
   "$PROBLEM_LIST_PATH/SYO175^5.p.out",
   "$PROBLEM_LIST_PATH/SYO178^5.p.out",
   "$PROBLEM_LIST_PATH/SYO179^5.p.out",
   "$PROBLEM_LIST_PATH/SYO180^5.p.out",
   "$PROBLEM_LIST_PATH/SYO183^5.p.out",
   "$PROBLEM_LIST_PATH/SYO183^6.p.out",
   "$PROBLEM_LIST_PATH/SYO184^5.p.out",
   "$PROBLEM_LIST_PATH/SYO185^5.p.out",
   "$PROBLEM_LIST_PATH/SYO186^5.p.out",
   "$PROBLEM_LIST_PATH/SYO187^5.p.out",
   "$PROBLEM_LIST_PATH/SYO188^5.p.out",
   "$PROBLEM_LIST_PATH/SYO189^5.p.out",
   "$PROBLEM_LIST_PATH/SYO190^5.p.out",
   "$PROBLEM_LIST_PATH/SYO191^5.p.out",
   "$PROBLEM_LIST_PATH/SYO192^5.p.out",
   "$PROBLEM_LIST_PATH/SYO193^5.p.out",
   "$PROBLEM_LIST_PATH/SYO194^5.p.out",
   "$PROBLEM_LIST_PATH/SYO195^5.p.out",
   "$PROBLEM_LIST_PATH/SYO196^5.p.out",
   "$PROBLEM_LIST_PATH/SYO197^5.p.out",
   "$PROBLEM_LIST_PATH/SYO198^5.p.out",
   "$PROBLEM_LIST_PATH/SYO199^5.p.out",
   "$PROBLEM_LIST_PATH/SYO200^5.p.out",
   "$PROBLEM_LIST_PATH/SYO202^5.p.out",
   "$PROBLEM_LIST_PATH/SYO203^5.p.out",
   "$PROBLEM_LIST_PATH/SYO204^5.p.out",
   "$PROBLEM_LIST_PATH/SYO205^5.p.out",
   "$PROBLEM_LIST_PATH/SYO206^5.p.out",
   "$PROBLEM_LIST_PATH/SYO207^5.p.out",
   "$PROBLEM_LIST_PATH/SYO212^5.p.out",
   "$PROBLEM_LIST_PATH/SYO214^5.p.out",
   "$PROBLEM_LIST_PATH/SYO215^5.p.out",
   "$PROBLEM_LIST_PATH/SYO216^5.p.out",
   "$PROBLEM_LIST_PATH/SYO217^5.p.out",
   "$PROBLEM_LIST_PATH/SYO218^5.p.out",
   "$PROBLEM_LIST_PATH/SYO219^5.p.out",
   "$PROBLEM_LIST_PATH/SYO220^5.p.out",
   "$PROBLEM_LIST_PATH/SYO221^5.p.out",
   "$PROBLEM_LIST_PATH/SYO223^5.p.out",
   "$PROBLEM_LIST_PATH/SYO225^5.p.out",
   "$PROBLEM_LIST_PATH/SYO226^5.p.out",
   "$PROBLEM_LIST_PATH/SYO227^5.p.out",
   "$PROBLEM_LIST_PATH/SYO228^5.p.out",
   "$PROBLEM_LIST_PATH/SYO229^5.p.out",
   "$PROBLEM_LIST_PATH/SYO230^5.p.out",
   "$PROBLEM_LIST_PATH/SYO231^5.p.out",
   "$PROBLEM_LIST_PATH/SYO232^5.p.out",
   "$PROBLEM_LIST_PATH/SYO233^5.p.out",
   "$PROBLEM_LIST_PATH/SYO234^5.p.out",
   "$PROBLEM_LIST_PATH/SYO235^5.p.out",
   "$PROBLEM_LIST_PATH/SYO236^5.p.out",
   "$PROBLEM_LIST_PATH/SYO237^5.p.out",
   "$PROBLEM_LIST_PATH/SYO238^5.p.out",
   "$PROBLEM_LIST_PATH/SYO244^5.p.out",
   "$PROBLEM_LIST_PATH/SYO246^5.p.out",
   "$PROBLEM_LIST_PATH/SYO249^5.p.out",
   "$PROBLEM_LIST_PATH/SYO252^5.p.out",
   "$PROBLEM_LIST_PATH/SYO253^5.p.out",
   "$PROBLEM_LIST_PATH/SYO255^5.p.out",
   "$PROBLEM_LIST_PATH/SYO256^5.p.out",
   "$PROBLEM_LIST_PATH/SYO257^5.p.out",
   "$PROBLEM_LIST_PATH/SYO258^5.p.out",
   "$PROBLEM_LIST_PATH/SYO259^5.p.out",
   "$PROBLEM_LIST_PATH/SYO260^5.p.out",
   "$PROBLEM_LIST_PATH/SYO261^5.p.out",
   "$PROBLEM_LIST_PATH/SYO262^5.p.out",
   "$PROBLEM_LIST_PATH/SYO263^5.p.out",
   "$PROBLEM_LIST_PATH/SYO264^5.p.out",
   "$PROBLEM_LIST_PATH/SYO265^5.p.out",
   "$PROBLEM_LIST_PATH/SYO266^5.p.out",
   "$PROBLEM_LIST_PATH/SYO267^5.p.out",
   "$PROBLEM_LIST_PATH/SYO268^5.p.out",
   "$PROBLEM_LIST_PATH/SYO270^5.p.out",
   "$PROBLEM_LIST_PATH/SYO274^5.p.out",
   "$PROBLEM_LIST_PATH/SYO276^5.p.out",
   "$PROBLEM_LIST_PATH/SYO277^5.p.out",
   "$PROBLEM_LIST_PATH/SYO281^5.p.out",
   "$PROBLEM_LIST_PATH/SYO282^5.p.out",
   "$PROBLEM_LIST_PATH/SYO285^5.p.out",
   "$PROBLEM_LIST_PATH/SYO286^5.p.out",
   "$PROBLEM_LIST_PATH/SYO289^5.p.out",
   "$PROBLEM_LIST_PATH/SYO290^5.p.out",
   "$PROBLEM_LIST_PATH/SYO291^5.p.out",
   "$PROBLEM_LIST_PATH/SYO292^5.p.out",
   "$PROBLEM_LIST_PATH/SYO293^5.p.out",
   "$PROBLEM_LIST_PATH/SYO296^5.p.out",
   "$PROBLEM_LIST_PATH/SYO298^5.p.out",
   "$PROBLEM_LIST_PATH/SYO299^5.p.out",
   "$PROBLEM_LIST_PATH/SYO301^5.p.out",
   "$PROBLEM_LIST_PATH/SYO303^5.p.out",
   "$PROBLEM_LIST_PATH/SYO305^5.p.out",
   "$PROBLEM_LIST_PATH/SYO306^5.p.out",
   "$PROBLEM_LIST_PATH/SYO307^5.p.out",
   "$PROBLEM_LIST_PATH/SYO308^5.p.out",
   "$PROBLEM_LIST_PATH/SYO310^5.p.out",
   "$PROBLEM_LIST_PATH/SYO311^5.p.out",
   "$PROBLEM_LIST_PATH/SYO314^5.p.out",
   "$PROBLEM_LIST_PATH/SYO315^5.p.out",
   "$PROBLEM_LIST_PATH/SYO317^5.p.out",
   "$PROBLEM_LIST_PATH/SYO324^5.p.out",
   "$PROBLEM_LIST_PATH/SYO334^5.p.out",
   "$PROBLEM_LIST_PATH/SYO344^5.p.out",
   "$PROBLEM_LIST_PATH/SYO345^5.p.out",
   "$PROBLEM_LIST_PATH/SYO346^5.p.out",
   "$PROBLEM_LIST_PATH/SYO347^5.p.out",
   "$PROBLEM_LIST_PATH/SYO348^5.p.out",
   "$PROBLEM_LIST_PATH/SYO349^5.p.out",
   "$PROBLEM_LIST_PATH/SYO350^5.p.out",
   "$PROBLEM_LIST_PATH/SYO351^5.p.out",
   "$PROBLEM_LIST_PATH/SYO352^5.p.out",
   "$PROBLEM_LIST_PATH/SYO353^5.p.out",
   "$PROBLEM_LIST_PATH/SYO354^5.p.out",
   "$PROBLEM_LIST_PATH/SYO355^5.p.out",
   "$PROBLEM_LIST_PATH/SYO356^5.p.out",
   "$PROBLEM_LIST_PATH/SYO357^5.p.out",
   "$PROBLEM_LIST_PATH/SYO358^5.p.out",
   "$PROBLEM_LIST_PATH/SYO359^5.p.out",
   "$PROBLEM_LIST_PATH/SYO360^5.p.out",
   "$PROBLEM_LIST_PATH/SYO361^5.p.out",
   "$PROBLEM_LIST_PATH/SYO362^5.p.out",
   "$PROBLEM_LIST_PATH/SYO363^5.p.out",
   "$PROBLEM_LIST_PATH/SYO364^5.p.out",
   "$PROBLEM_LIST_PATH/SYO365^5.p.out",
   "$PROBLEM_LIST_PATH/SYO366^5.p.out",
   "$PROBLEM_LIST_PATH/SYO367^5.p.out",
   "$PROBLEM_LIST_PATH/SYO368^5.p.out",
   "$PROBLEM_LIST_PATH/SYO369^5.p.out",
   "$PROBLEM_LIST_PATH/SYO370^5.p.out",
   "$PROBLEM_LIST_PATH/SYO371^5.p.out",
   "$PROBLEM_LIST_PATH/SYO372^5.p.out",
   "$PROBLEM_LIST_PATH/SYO373^5.p.out",
   "$PROBLEM_LIST_PATH/SYO374^5.p.out",
   "$PROBLEM_LIST_PATH/SYO375^5.p.out",
   "$PROBLEM_LIST_PATH/SYO376^5.p.out",
   "$PROBLEM_LIST_PATH/SYO378^5.p.out",
   "$PROBLEM_LIST_PATH/SYO379^5.p.out",
   "$PROBLEM_LIST_PATH/SYO380^5.p.out",
   "$PROBLEM_LIST_PATH/SYO381^5.p.out",
   "$PROBLEM_LIST_PATH/SYO382^5.p.out",
   "$PROBLEM_LIST_PATH/SYO383^5.p.out",
   "$PROBLEM_LIST_PATH/SYO384^5.p.out",
   "$PROBLEM_LIST_PATH/SYO385^5.p.out",
   "$PROBLEM_LIST_PATH/SYO386^5.p.out",
   "$PROBLEM_LIST_PATH/SYO387^5.p.out",
   "$PROBLEM_LIST_PATH/SYO388^5.p.out",
   "$PROBLEM_LIST_PATH/SYO389^5.p.out",
   "$PROBLEM_LIST_PATH/SYO390^5.p.out",
   "$PROBLEM_LIST_PATH/SYO391^5.p.out",
   "$PROBLEM_LIST_PATH/SYO392^1.p.out",
   "$PROBLEM_LIST_PATH/SYO393^1.p.out",
   "$PROBLEM_LIST_PATH/SYO394^1.p.out",
   "$PROBLEM_LIST_PATH/SYO395^1.p.out",
   "$PROBLEM_LIST_PATH/SYO396^1.p.out",
   "$PROBLEM_LIST_PATH/SYO397^1.p.out",
   "$PROBLEM_LIST_PATH/SYO398^1.p.out",
   "$PROBLEM_LIST_PATH/SYO399^1.p.out",
   "$PROBLEM_LIST_PATH/SYO400^1.p.out",
   "$PROBLEM_LIST_PATH/SYO401^1.p.out",
   "$PROBLEM_LIST_PATH/SYO402^1.p.out",
   "$PROBLEM_LIST_PATH/SYO403^1.p.out",
   "$PROBLEM_LIST_PATH/SYO404^1.p.out",
   "$PROBLEM_LIST_PATH/SYO405^1.p.out",
   "$PROBLEM_LIST_PATH/SYO406^1.p.out",
   "$PROBLEM_LIST_PATH/SYO407^1.p.out",
   "$PROBLEM_LIST_PATH/SYO408^1.p.out",
   "$PROBLEM_LIST_PATH/SYO409^1.p.out",
   "$PROBLEM_LIST_PATH/SYO410^1.p.out",
   "$PROBLEM_LIST_PATH/SYO411^1.p.out",
   "$PROBLEM_LIST_PATH/SYO412^1.p.out",
   "$PROBLEM_LIST_PATH/SYO413^1.p.out",
   "$PROBLEM_LIST_PATH/SYO414^1.p.out",
   "$PROBLEM_LIST_PATH/SYO415^1.p.out",
   "$PROBLEM_LIST_PATH/SYO416^1.p.out",
   "$PROBLEM_LIST_PATH/SYO417^1.p.out",
   "$PROBLEM_LIST_PATH/SYO418^1.p.out",
   "$PROBLEM_LIST_PATH/SYO419^1.p.out",
   "$PROBLEM_LIST_PATH/SYO420^1.p.out",
   "$PROBLEM_LIST_PATH/SYO421^1.p.out",
   "$PROBLEM_LIST_PATH/SYO422^1.p.out",
   "$PROBLEM_LIST_PATH/SYO423^1.p.out",
   "$PROBLEM_LIST_PATH/SYO424^1.p.out",
   "$PROBLEM_LIST_PATH/SYO425^1.p.out",
   "$PROBLEM_LIST_PATH/SYO426^1.p.out",
   "$PROBLEM_LIST_PATH/SYO427^1.p.out",
   "$PROBLEM_LIST_PATH/SYO428^1.p.out",
   "$PROBLEM_LIST_PATH/SYO429^1.p.out",
   "$PROBLEM_LIST_PATH/SYO430^1.p.out",
   "$PROBLEM_LIST_PATH/SYO431^1.p.out",
   "$PROBLEM_LIST_PATH/SYO432^1.p.out",
   "$PROBLEM_LIST_PATH/SYO433^1.p.out",
   "$PROBLEM_LIST_PATH/SYO434^1.p.out",
   "$PROBLEM_LIST_PATH/SYO435^1.p.out",
   "$PROBLEM_LIST_PATH/SYO436^1.p.out",
   "$PROBLEM_LIST_PATH/SYO437^1.p.out",
   "$PROBLEM_LIST_PATH/SYO438^1.p.out",
   "$PROBLEM_LIST_PATH/SYO439^1.p.out",
   "$PROBLEM_LIST_PATH/SYO440^1.p.out",
   "$PROBLEM_LIST_PATH/SYO441^1.p.out",
   "$PROBLEM_LIST_PATH/SYO442^1.p.out",
   "$PROBLEM_LIST_PATH/SYO443^1.p.out",
   "$PROBLEM_LIST_PATH/SYO444^1.p.out",
   "$PROBLEM_LIST_PATH/SYO445^1.p.out",
   "$PROBLEM_LIST_PATH/SYO446^1.p.out",
   "$PROBLEM_LIST_PATH/SYO447^1.p.out",
   "$PROBLEM_LIST_PATH/SYO448^1.p.out",
   "$PROBLEM_LIST_PATH/SYO449^1.p.out",
   "$PROBLEM_LIST_PATH/SYO450^3.p.out",
   "$PROBLEM_LIST_PATH/SYO450^4.p.out",
   "$PROBLEM_LIST_PATH/SYO450^5.p.out",
   "$PROBLEM_LIST_PATH/SYO450^6.p.out",
   "$PROBLEM_LIST_PATH/SYO451^5.p.out",
   "$PROBLEM_LIST_PATH/SYO451^6.p.out",
   "$PROBLEM_LIST_PATH/SYO454^6.p.out",
   "$PROBLEM_LIST_PATH/SYO455^2.p.out",
   "$PROBLEM_LIST_PATH/SYO455^3.p.out",
   "$PROBLEM_LIST_PATH/SYO455^4.p.out",
   "$PROBLEM_LIST_PATH/SYO455^5.p.out",
   "$PROBLEM_LIST_PATH/SYO455^6.p.out",
   "$PROBLEM_LIST_PATH/SYO456^4.p.out",
   "$PROBLEM_LIST_PATH/SYO456^6.p.out",
   "$PROBLEM_LIST_PATH/SYO457^3.p.out",
   "$PROBLEM_LIST_PATH/SYO457^4.p.out",
   "$PROBLEM_LIST_PATH/SYO457^5.p.out",
   "$PROBLEM_LIST_PATH/SYO457^6.p.out",
   "$PROBLEM_LIST_PATH/SYO458^2.p.out",
   "$PROBLEM_LIST_PATH/SYO458^3.p.out",
   "$PROBLEM_LIST_PATH/SYO458^4.p.out",
   "$PROBLEM_LIST_PATH/SYO458^5.p.out",
   "$PROBLEM_LIST_PATH/SYO458^6.p.out",
   "$PROBLEM_LIST_PATH/SYO459^4.p.out",
   "$PROBLEM_LIST_PATH/SYO459^6.p.out",
   "$PROBLEM_LIST_PATH/SYO460^1.p.out",
   "$PROBLEM_LIST_PATH/SYO460^2.p.out",
   "$PROBLEM_LIST_PATH/SYO460^3.p.out",
   "$PROBLEM_LIST_PATH/SYO460^4.p.out",
   "$PROBLEM_LIST_PATH/SYO460^5.p.out",
   "$PROBLEM_LIST_PATH/SYO460^6.p.out",
   "$PROBLEM_LIST_PATH/SYO462^2.p.out",
   "$PROBLEM_LIST_PATH/SYO462^3.p.out",
   "$PROBLEM_LIST_PATH/SYO462^4.p.out",
   "$PROBLEM_LIST_PATH/SYO462^5.p.out",
   "$PROBLEM_LIST_PATH/SYO462^6.p.out",
   "$PROBLEM_LIST_PATH/SYO463^5.p.out",
   "$PROBLEM_LIST_PATH/SYO463^6.p.out",
   "$PROBLEM_LIST_PATH/SYO464^4.p.out",
   "$PROBLEM_LIST_PATH/SYO464^5.p.out",
   "$PROBLEM_LIST_PATH/SYO464^6.p.out",
   "$PROBLEM_LIST_PATH/SYO468^6.p.out",
   "$PROBLEM_LIST_PATH/SYO469^5.p.out",
   "$PROBLEM_LIST_PATH/SYO469^6.p.out",
   "$PROBLEM_LIST_PATH/SYO470^6.p.out",
   "$PROBLEM_LIST_PATH/SYO471^6.p.out",
   "$PROBLEM_LIST_PATH/SYO474^6.p.out",
   "$PROBLEM_LIST_PATH/SYO475^6.p.out",
   "$PROBLEM_LIST_PATH/SYO476^6.p.out",
   "$PROBLEM_LIST_PATH/SYO478^6.p.out",
   "$PROBLEM_LIST_PATH/SYO480^6.p.out",
   "$PROBLEM_LIST_PATH/SYO481^6.p.out",
   "$PROBLEM_LIST_PATH/SYO482^6.p.out",
   "$PROBLEM_LIST_PATH/SYO483^6.p.out",
   "$PROBLEM_LIST_PATH/SYO485^6.p.out",
   "$PROBLEM_LIST_PATH/SYO487^6.p.out",
   "$PROBLEM_LIST_PATH/SYO488^6.p.out",
   "$PROBLEM_LIST_PATH/SYO495^6.p.out",
   "$PROBLEM_LIST_PATH/SYO497^6.p.out",
   "$PROBLEM_LIST_PATH/SYO499^1.p.out",
   "$PROBLEM_LIST_PATH/SYO500^1.p.out",
   "$PROBLEM_LIST_PATH/SYO501^1.p.out",
   "$PROBLEM_LIST_PATH/SYO502^1.p.out",
   "$PROBLEM_LIST_PATH/SYO503^1.p.out",
   "$PROBLEM_LIST_PATH/SYO504^1.p.out",
   "$PROBLEM_LIST_PATH/SYO506^1.p.out",
   "$PROBLEM_LIST_PATH/SYO507^1.p.out",
   "$PROBLEM_LIST_PATH/SYO512^1.p.out",
   "$PROBLEM_LIST_PATH/SYO516^1.p.out",
   "$PROBLEM_LIST_PATH/SYO520^1.p.out",
   "$PROBLEM_LIST_PATH/SYO526^1.p.out",
   "$PROBLEM_LIST_PATH/SYO527^1.p.out",
   "$PROBLEM_LIST_PATH/SYO549^1.p.out",
   "$PROBLEM_LIST_PATH/SYO550^1.p.out",
   "$PROBLEM_LIST_PATH/SYO551^1.p.out",
   "$PROBLEM_LIST_PATH/SYO552^1.p.out",
   "$PROBLEM_LIST_PATH/SYO553^1.p.out",
   "$PROBLEM_LIST_PATH/SYO554^1.p.out",
   "$PROBLEM_LIST_PATH/SYO557^1.p.out"]
*}

ML {*
List.app do_file (tptp_files @ tptp_files2 @ tptp_files3)
*}

end
